@@ -88,19 +88,19 @@ int auth_login(user,password)
 void network_printf(char * data, ...)
 {
   va_list param;
-  int r, s;
-  char * buffer = emalloc(8192);
+  int r, s = 16384;
+  char * buffer = emalloc(s);
   int len, n = 0;
   signal(SIGPIPE, sighand_pipe);
   va_start(param, data);
 
-  s = 8192;
+ 
   for(;;)
   {
    r = vsnprintf(buffer, s, data, param);
    if(r >= 0 && r < s)break;
    s = r > s ? r + 1 : s * 2;
-   buffer = realloc(buffer, s);
+   buffer = erealloc(buffer, s);
   }
   len = strlen(buffer);
   while(n < len)
