@@ -44,8 +44,6 @@
 
 
 
-
-
 	
 #define MAX_TMPFILES 256
 struct backend backends[MAX_TMPFILES];
@@ -53,7 +51,7 @@ struct backend backends[MAX_TMPFILES];
 
 
 
-void be_info(be, str)
+void be_info(int be, const char * str)
 {
 #ifdef BACKEND_DEBUG
  printf("%s(%d) disposable:%d, fd:%d, %s\n",
@@ -95,7 +93,8 @@ backend_init(fname)
  strcat(tmpfile, "/nessus-XXXXXX");
 #ifdef HAVE_MKSTEMP
  backends[i].fd = mkstemp(tmpfile);
- fchmod(backends[i].fd, 0600); /* glibc bug */
+ if( backends[i].fd >= 0 )
+ 	fchmod(backends[i].fd, 0600); /* glibc bug */
 #else
  mktemp(tmpfile);
  backends[i].fd = open(tmpfile, O_CREAT|O_EXCL|O_RDWR, 0600); 
@@ -103,7 +102,8 @@ backend_init(fname)
  if(backends[i].fd < 0)
  {
    show_error(strerror(errno));
-   exit(0);
+   efree(&tmpfile);
+   return -1;
  }
  backends[i].disposable = 1;
  }
@@ -111,18 +111,14 @@ backend_init(fname)
  {
   if((backends[i].fd = open(fname,O_RDONLY)) < 0)
    {
-   perror("open ");
+   show_error(strerror(errno));
    return -1;
    }
   tmpfile = estrdup(fname);
   backends[i].disposable = 0;
  }
  
- if(backends[i].fd < 0)
-  {
-  show_error(strerror(errno));
-  return -1;
-  }
+ 
  backends[i].fname = tmpfile; 
  backends[i].backend_type = BACKEND_NSR;
  
@@ -252,13 +248,40 @@ backend_insert_report_data(be, subnet, host, port, script_id, severity, data)
  return 0;
 }
 
+int _backend_cmpcb(void *unused, harglst *not_used, hargkey_t *lKey,
+	hargtype_t lType, hargkey_t *rKey, hargtype_t rType) 
+{
+	in_addr_t rin,lin;
+	unsigned long rip,lip;
+	rin = inet_addr(rKey);
+	lin = inet_addr(lKey);
+	if(rin == -1) {
+		if(lin == -1) {
+			return strcmp(rKey,lKey);
+		} else {
+			return 1;
+		}
+	} else {
+		if(lin == -1) {
+			return -1;
+		} else {
+			rip = ntohl(rin);
+			lip = ntohl(lin);
+			if(lip < rip ) { return 1; }
+			if(lip == rip) { return 0; } 
+			if(lip > rip)  { return -1; }
+		}
+	}
+	return 0;
+}
+
+
 
 struct arglist *
 backend_convert(be)
  int be;
 {
  harglst * hhosts;
- hargwalk * hw;
  FILE * fd = fopen(backends[be].fname, "r");
  char buf[65535];
  char * current_hostname = NULL;
@@ -266,6 +289,7 @@ backend_convert(be)
  struct arglist * nhosts = NULL;
  char * key;
  int line = 0;
+ unsigned x;
 
  if(!fd)
   {
@@ -415,10 +439,11 @@ parse_error:
  /*
   *  harglist -> arglist conversion
   */
- hw = harg_walk_init(hhosts);
+ harg_csort(hhosts,_backend_cmpcb,"heh");
+ harg_sort(hhosts);
+ x = 0;
  nhosts = emalloc(sizeof(struct arglist));
- while((key = (char*)harg_walk_next(hw)))
- {
+ while((key = (char *)harg_get_nth(hhosts,x))) {
   struct arglist * new = emalloc(sizeof(struct arglist));
   struct arglist * h = harg_get_ptr(hhosts, key);
   new->name = strdup(key);
@@ -427,14 +452,12 @@ parse_error:
   new->value = h;
   new->next = nhosts;
   nhosts = new;
+  x++;
  }
- /*harg_walk_stop(hw);*/
- harg_close(hhosts);
+
  return nhosts;
 }
 
-
-
 int
 backend_close(be)
  int be;
@@ -444,8 +467,11 @@ backend_close(be)
  if(backends[be].mmap)
  {
   struct stat  buf;
+  int len;
+
   fstat(backends[be].fd, &buf);
-  munmap(backends[be].mmap, buf.st_size);
+  len = (int)buf.st_size;
+  munmap(backends[be].mmap, len);
   backends[be].mmap = NULL;
   efree(&backends[be].lines);
   efree(&backends[be].eols);
