@@ -557,6 +557,15 @@ _cli_sql_dump_plugins(p)
  
  
  m =  arg_get_value(q, "BUGTRAQ_ID");
+ if(m != NULL)
+  {
+  m = sql_addslashes(m);
+  printf("'%s',", m);
+  efree(&m);
+  }
+ else printf("'',");
+ 
+  m =  arg_get_value(q, "XREFS");
  if(m != NULL)
   {
   m = sql_addslashes(m);
@@ -566,8 +575,6 @@ _cli_sql_dump_plugins(p)
  else printf("'');\n");
  
  
- 
- 
   _cli_sql_dump_plugins(p->next);
  }
 }
@@ -608,6 +615,13 @@ _cli_dump_plugins(plugins)
   printf("%s|", var);
   efree(&var);
   
+  var = addslashes(arg_get_value(plugins->value, "BUGTRAQ_ID"));
+  printf("%s|", var);
+  efree(&var);
+  
+  var = addslashes(arg_get_value(plugins->value, "XREFS"));
+  printf("%s|", var);
+  efree(&var);
    
   var = addslashes(arg_get_value(plugins->value, "DESCRIPTION"));
   printf("%s\n", var);
@@ -634,6 +648,7 @@ cli_sql_dump_plugins(cli)
  printf(" version varchar(255),\n");
  printf(" cve_id varchar(255),\n");
  printf(" bugtraq_id varchar(255),\n");
+ printf(" xref blob,\n");
  printf(" primary key (id));\n");
  _cli_sql_dump_plugins(Plugins);
  _cli_sql_dump_plugins(Scanners);
