@@ -118,8 +118,16 @@ parse_plugin(buf)
    
     str = parse_separator(buf + l);
     if(str != NULL)
+     { 
      arg_add_value(plugin, "BUGTRAQ_ID", ARG_STRING, strlen(str), estrdup(str));
+     l += strlen(str) + 5;
+     str = parse_separator(buf + l);
+     if( str != NULL )arg_add_value(plugin, "XREFS", ARG_STRING, strlen(str), estrdup(str));
+     }
    }
+   
+   
+ 
   }
 	
    /*
@@ -216,7 +224,7 @@ comm_plugin_upload(fname)
  char buff[2048];
  char *content;
  char *e;
- 
+ int len;
  e = strrchr(fname, '/');
  if(!e)e = fname;
  else e++;
@@ -230,12 +238,16 @@ comm_plugin_upload(fname)
   return -1;
  }
  
- fstat(fd, &stt);
+ if( fstat(fd, &stt) < 0 )
+ {
+  perror("fstat ");
+ }
+ len = (int)stt.st_size;
  network_printf("CLIENT <|> ATTACHED_PLUGIN\n");
  network_printf("name: %s\n", e);
  network_printf("content: octet/stream\n");
- network_printf("bytes: %ld\n", stt.st_size);
- content = mmap(NULL, stt.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
+ network_printf("bytes: %d\n", len);
+ content = mmap(NULL, len, PROT_READ, MAP_PRIVATE, fd, 0);
  if(content == MAP_FAILED)
   {
    show_error(strerror(errno));
@@ -244,21 +256,21 @@ comm_plugin_upload(fname)
   }
   
   
- while(tot != stt.st_size)
+ while(tot != len)
  {
   int e;
-  e = write_stream_connection(GlobalSocket, content + tot, stt.st_size - tot);
+  e = write_stream_connection(GlobalSocket, content + tot, len - tot);
   if(e < 0)
   {
    show_error(strerror(errno));
-   munmap(content, stt.st_size);
+   munmap(content, len);
    close(fd);
    return -1;
   }
   tot += e;
  }
  
- munmap(content, stt.st_size);
+ munmap(content, len);
  close(fd);
  network_gets(buff, sizeof(buff) - 1); /* Confirmation message */
  return 0;
@@ -757,6 +769,7 @@ comm_send_preferences(preferences)
  else
   return gui_comm_send_preferences(preferences);
 }
+ int len;
 
 int
 comm_send_file(fname)
@@ -767,8 +780,9 @@ comm_send_file(fname)
  long tot = 0;
  char buff[1024];
  
- if(!fname || !strlen(fname))
+ if(!fname || fname[0] == '\0')
   return 0;
+ len = (int)stt.st_size;
   
  if(fd < 0)
  {
@@ -777,12 +791,12 @@ comm_send_file(fname)
   return -1;
  }
  
- fstat(fd, &stt);
+ if ( fstat(fd, &stt) < 0 ) perror("fstat ");
  network_printf("CLIENT <|> ATTACHED_FILE\n");
  network_printf("name: %s\n", fname);
  network_printf("content: octet/stream\n");
- network_printf("bytes: %ld\n", stt.st_size);
- tot = stt.st_size;
+ tot = (int)stt.st_size;
+ network_printf("bytes: %d\n", tot);
  while(tot > 0)
  {
   int m = 0, n;
