@@ -132,6 +132,8 @@ be_index_keywords(be)
     
     if(!flag)
     {
+     if ( field[j] == NULL )
+       	return -1;
     f = emalloc(sizeof(*f));
     f->value = emalloc(strlen(field[j])+1);
     strcpy(f->value, field[j]);
@@ -263,9 +265,11 @@ read_line(be, buf, size)
  if(!backends[be].mmap_attempts)
  {
   struct stat buf;
+  int len;
   fstat(backends[be].fd, &buf);
+  len = (int)buf.st_size;
   if((backends[be].mmap = 
-   	mmap(NULL, buf.st_size, PROT_READ, MAP_SHARED, backends[be].fd, 0)) 
+   	mmap(NULL, len, PROT_READ, MAP_SHARED, backends[be].fd, 0)) 
 			== MAP_FAILED)
    	backends[be].mmap = NULL;
   else
