@@ -1,10 +1,9 @@
 /* Nessus
- * Copyright (C) 1998 Renaud Deraison
+ * Copyright (C) 1998 - 2001 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 2,
+ * as published by the Free Software Foundation
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,6 +14,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  */
  
 #include <includes.h>
@@ -36,6 +45,7 @@ show_dialog
   fprintf (stderr, "*** %s\n", error_text);
 }
 #else /* USE_GTK */
+#include "gtk-compat.h"
 #include <gtk/gtk.h>
 #include "xpm/error.xpm"
 #include "xpm/warning.xpm"
@@ -88,6 +98,7 @@ show_dialog(error_text, type)
 	name = "Error";
 	break;
   }
+ 
   dialog = gtk_window_new(GTK_WINDOW_DIALOG);
   gtk_window_set_title(GTK_WINDOW(dialog), name);
   gtk_signal_connect (GTK_OBJECT (dialog), "delete_event",
@@ -158,9 +169,12 @@ static void show_dialog_and_wait_cb(gw, ok)
  GtkWidget* gw;
  int *ok;
 {
- gtk_grab_remove(gw->parent);
- close_window(NULL, gw->parent);
+ GtkWidget* dialog = gw->parent->parent->parent;
+ gtk_grab_remove(dialog);
+ close_window(NULL, dialog);
+ gtk_widget_destroy(dialog);
  *ok = 1;
+ gtk_main_quit();
 }
 
 void show_dialog_and_wait_build(int * ok, char * error_text, int type)
@@ -193,7 +207,7 @@ void show_dialog_and_wait_build(int * ok, char * error_text, int type)
   gtk_widget_realize(dialog);
   gtk_window_set_title(GTK_WINDOW(dialog), name);
   gtk_signal_connect (GTK_OBJECT (dialog), "delete_event",
-		      GTK_SIGNAL_FUNC (delete_event), NULL); 
+		      GTK_SIGNAL_FUNC (show_dialog_and_wait_cb), ok); 
   gtk_window_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
   vbox = gtk_vbox_new(FALSE, 15);
   gtk_container_border_width(GTK_CONTAINER(dialog), 10);
@@ -262,8 +276,7 @@ void show_dialog_and_wait(char * error, int type)
  else
  {
   show_dialog_and_wait_build(&ok, error, type);
-  while(!ok)
-   while(gtk_events_pending())gtk_main_iteration();
+  gtk_main();
  }
 }
                                 
