@@ -19,8 +19,22 @@
 #ifndef _NESSUSC_ERROR_DIALOG_H
 #define _NESSUSC_ERROR_DIALOG_H
 
-extern void show_error(char * error_text);
-extern void show_error_and_wait_build(int * ok, char * error_text);
-extern void show_error_and_wait(char * error);
+#define DIALOG_TYPE_INFO 0
+#define DIALOG_TYPE_WARNING 1
+#define DIALOG_TYPE_ERROR 2
+
+
+#define show_error(x) show_dialog(x, DIALOG_TYPE_ERROR)
+#define show_warning(x) show_dialog(x, DIALOG_TYPE_WARNING)
+#define show_info(x) show_dialog(x, DIALOG_TYPE_INFO)
+
+#define show_error_and_wait(x) show_dialog_and_wait(x, DIALOG_TYPE_ERROR)
+#define show_warning_and_wait(x) show_dialog_and_wait(x, DIALOG_TYPE_WARNING)
+#define show_info_and_wait(x) show_dialog_and_wait(x, DIALOG_TYPE_INFO)
+
+
+extern void show_dialog(char * error_text, int type);
+extern void show_dialog_and_wait_build(int * ok, char * error_text, int type);
+extern void show_dialog_and_wait(char * error, int type);
 
 #endif
