@@ -1,10 +1,9 @@
 /* Nessus
- * Copyright (C) 2000 Renaud Deraison
+ * Copyright (C) 2000 - 2003 Renaud Deraison
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 2,
+ * as published by the Free Software Foundation
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,6 +14,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  *
  * Professional looking, flashy-flashy report.
  *
@@ -66,25 +75,12 @@
 #include "nsr_output.h"
 
 
-static char* strcasestr(char*, char *);
+static char* ne_strcasestr(char*, char *);
 static void insert_img(FILE *, char*);
 
 
-static void complete(float * risks, int pad)
-{
- int i;
- int min = 100, imin = 0;
+extern int out_graph(short, short, FILE *, GDC_CHART_T, int, char **, int, float *);
 
- for(i=0;i<4;i++)
-  {
-  int a = risks[i];
-  if(a && (a <= min)){
-  	min = a;
-	imin = i;
-	}
-  }
-  risks[imin] += pad; 
-}
 
 
 /*
@@ -92,7 +88,7 @@ static void complete(float * risks, int pad)
  */
  
 static char * 
-strcasestr(char * haystack, char * needle)
+ne_strcasestr(char * haystack, char * needle)
 {
  int len_h = strlen(haystack);
  int len_needle = strlen(needle);
@@ -104,7 +100,7 @@ strcasestr(char * haystack, char * needle)
   else
   {
    len_h --;
-   haystack+=sizeof(char);
+   haystack++;
   }
  }
  return NULL;
@@ -130,21 +126,21 @@ static int risk_severity_by_kind(reports, risks)
 {
 while(reports && reports->next)
  {
-   if(strcasestr(reports->value, "Risk factor : Low"))
+   if(ne_strcasestr(reports->value, "Risk factor : Low"))
     risks[0] = risks[0] + 1;
    else
     {
-    if(strcasestr(reports->value,"Risk factor : Medium"))
+    if(ne_strcasestr(reports->value,"Risk factor : Medium"))
       risks[1] = risks[1] + 1;
     else 
      {
-      if(strcasestr(reports->value, "Risk factor : Serious"))
+      if(ne_strcasestr(reports->value, "Risk factor : Serious"))
       	 risks[2] = risks[2] + 1;
      else 
         {
-	 if(strcasestr(reports->value, "Risk factor : High")||
-             strcasestr(reports->value, "Risk factor : Very High")||
-	     strcasestr(reports->value, "Risk factor : Critical"))
+	 if(ne_strcasestr(reports->value, "Risk factor : High")||
+             ne_strcasestr(reports->value, "Risk factor : Very High")||
+	     ne_strcasestr(reports->value, "Risk factor : Critical"))
               risks[3] = risks[3] + 1;
           else
 	  	/* Not a security problem - skip */
@@ -193,33 +189,13 @@ static int risk_severity_by_host(host, risks)
 static int risk_severity(hosts, risks)
  struct arglist * hosts;
  float *risks;
-{
- float total;
- 
- bzero(risks, sizeof(int)*4);
+{ 
+ bzero(risks, sizeof(float)*5);
  while(hosts && hosts->next)
  {
   risk_severity_by_host(hosts->value, risks);
   hosts = hosts->next;
  }
- total = risks[0] + risks[1] + risks[2] + risks[3];
- if(total)
- {
-  int a, b, c, d;
-  a =  (risks[0]*100)/total;
-  b =  (risks[1]*100)/total;
-  c =  (risks[2]*100)/total;
-  d =  (risks[3]*100)/total;
-  
-  
-  risks[0] = a;
-  risks[1] = b;
-  risks[2] = c;
-  risks[3] = d;
-  
-  if(a+b+c+d != 100)complete(risks, 100-(a+b+c+d));
- 
- }
  return 0;
 } 
 
@@ -557,36 +533,91 @@ most_used_operating_systems(hosts, names, values, n)
 			Single host report
 			
 -----------------------------------------------------------------------------*/
-
-static void 
-print_data_with_cve_link(file, str)
+/* All the cross references (CVE, BID) have the same format - XREF: <num>,...<br> */
+static char * 
+extract_xref(file, str, url)
  FILE * file;
- char * str;
+ char * str, * url;
 {
- char * t;
- if(!(t = strstr(str, "CVE : ")))
-   fprintf(file, "%s", str);
- else
+ while(str != NULL && strncmp(str, "<br>", 4) != 0)
    {
-    char * cve;
-    char * e;
-    char old;
-    t[0] = 0;
-    fprintf(file, "%s", str);
-    t[0] = 'C';
-    
-    cve = t + sizeof(char)*(strlen("CVE : "));
-    e = cve;
-    while(isalnum(e[0]) || (e[0]=='-'))e+=sizeof(char);
-    old = e[0];
-    e[0]='\0';
-    fprintf(file, "<a href=\"http://cgi.nessus.org/cve.php3?cve=%s\">",cve);
-    fprintf(file, "%s", t);
-    fprintf(file, "</a>");
-    e[0]=old;
-    fprintf(file, "%s", e);
+    char * e1 = strchr(str, ',');
+    char * e2 = strchr(str, '<');
+    char tmp = '\0';
+    if((e1 > e2) || (e1 == NULL))e1 = e2;
+   
+   
+    if(e1 != NULL)
+    {
+     tmp = e1[0];
+     e1[0] = '\0';
+    }
+    fprintf(file, "<a href=\"%s%s\">%s</a>", url, str, str);
+    str = e1;
+    if(e1 != NULL)
+    {
+     e1[0] = tmp;
+   
+     if(tmp == ','){
+     	fputc(',', file);
+	fputc(' ', file);
+	str ++;
+	str ++;
+	}
+     else
+        fputc('<', file);
+    }
    }
+  return str;
 }
+ 
+static void 
+print_data_with_links(file, str, plugin_id)
+ FILE * file;
+ char * str, * plugin_id;
+{
+ while(str != NULL && str[0] != '\0')
+ {
+  if(strncmp(str, "http:", 5) == 0)
+  {
+   char * e1, * e2;
+   char tmp = 0;
+   
+   e1 = strchr(str, ' ');
+   e2 = strstr(str, "<br>");
+   if((e1 > e2) || (e1 == NULL))e1 = e2;
+   
+   if(e1 != NULL)
+   {
+    tmp = e1[0];
+    e1[0] = '\0';
+   }
+   fprintf(file, "<a href=\"%s\">%s</a>", str, str);
+   str += strlen(str) - 1;
+   if(e1 != NULL)
+   {
+    e1[0] = tmp;
+   }
+  }
+  else if(strncmp(str, "CVE : ", 6) == 0)
+  {
+   fprintf(file, "CVE : ");
+   str += 6;
+   str = extract_xref(file, str, "http://cgi.nessus.org/cve.php3?cve=");
+  }
+  else if(strncmp(str, "BID : ", 6) == 0)
+  {
+  fprintf(file, "BID : ");
+  str += 6;
+  str = extract_xref(file, str, "http://cgi.nessus.org/bid.php3?bid=");
+  }
+  else fputc(str[0], file);
+  str++;
+ }
+ 
+ fprintf(file, "Nessus ID : <a href=\"http://cgi.nessus.org/nessus_id.php3?id=%s\">%s</a>", plugin_id, plugin_id);
+}
+
 static char * convert_cr_to_html(str)
  char * str;
 {
@@ -708,6 +739,10 @@ host_details(file, hosts)
    fprintf(file, "[<a href=\"../index.html\">Back to the index</a>]<p>\n");
  hostname = hosts->name;
  ports = arg_get_value(hosts->value, "PORTS");
+ name = portname_to_ahref("toc", hostname);
+ fprintf(file, "<a name=\"%s\"></a>\n", name);
+ efree(&name);
+
  if(ports)
  {
   struct arglist * open = ports;
@@ -772,7 +807,7 @@ host_details(file, hosts)
       efree(&name);		
       fprintf(file, "<FONT COLOR=\"#FF0000\">");
       fprintf(file, "<b>Vulnerability found on port %s</b></FONT><p><ul>\n",port);
-      print_data_with_cve_link(file, desc);
+      print_data_with_links(file, desc, report->name);
       fprintf(file, "<p></ul>\n");
       efree(&desc);
      }
@@ -803,7 +838,7 @@ host_details(file, hosts)
       fprintf(file, "<FONT COLOR=\"#660000\">");		
      fprintf(file, "<b>Warning found on port %s</b></FONT><p><ul><p>\n", port);
      efree(&name);	
-     print_data_with_cve_link(file, desc);
+     print_data_with_links(file, desc, info->name);
      fprintf(file, "<p></ul>\n");
      efree(&desc);
      }  
@@ -832,7 +867,7 @@ host_details(file, hosts)
       		name);
      fprintf(file, "<b>Information found on port %s</b><p><ul><p>\n", port);
      efree(&name);	
-     print_data_with_cve_link(file, desc);
+     print_data_with_links(file, desc, note->name);
      fprintf(file, "<p></ul>\n");
      efree(&desc);
      }  
@@ -884,28 +919,16 @@ create_host_report(struct arglist * host)
     
  risk_severity_by_port(arg_get_value(host->value, "PORTS"), risks);
  total = risks[0] + risks[1] + risks[2] + risks[3];
- if(total)
- {
-  int a,b,c,d;
-  
-  a = (risks[0]*100)/total;
-  b = (risks[1]*100)/total;
-  c = (risks[2]*100)/total;
-  d = (risks[3]*100)/total;
-  
-  risks[0] =  (float)a;
-  risks[1] =  (float)b;
-  risks[2] =  (float)c;
-  risks[3] =  (float)d;
-  if((a+b+c+d) != 100)complete(risks, 100-(a+b+c+d));
- }
+
  f = fopen("index.html", "w");
  if(f)
  {
    char * lbl[] = {"Low", "Medium", "Serious", "High"};
    int	expl[] = { 0, 0, 0, 20};
 
-   unsigned long   clr[] = {  0xFFFF80L, 0x80FF80L, 0xFF80FFL, 0xFF4040L};
+   unsigned long   clr[] = { 0x80FF80L, 0xFFFF80L, 0xFF80FFL, 0xFF4040L};
+   int risk_count = 4;
+   int non_zero_risks = 0;
   
    FILE * pie;
    fprintf(f, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\">\n");
@@ -940,7 +963,33 @@ create_host_report(struct arglist * host)
     GDC_image = NULL;
     GDCPIE_missing = NULL;
     GDCPIE_percent_labels = GDCPIE_PCT_RIGHT;
-    pie_gif(480, 360, pie, GDC_3DPIE, 4, lbl, risks);
+
+    /* remove zero elements */
+    {
+     int j;
+     for (j=0; j<risk_count; j++)
+     {
+      if ( risks[j]  == 0) { 
+        int i;
+	for(i=j;i<risk_count - 1;i++)
+	{
+         risks[  i ] = risks[ i + 1 ];
+         clr[ i ]   = clr[ i + 1 ];
+         lbl[ i ]   = lbl[ i + 1 ];
+	}
+      } else {
+       non_zero_risks++;
+      }
+     }
+    }
+    if (non_zero_risks>1) { /* is 1 or more as total > 0 */
+     expl[non_zero_risks-1] = 20;
+    }
+    
+    
+    risk_count = non_zero_risks;
+
+    pie_gif(480, 360, pie, GDC_3DPIE, risk_count, lbl, risks);
     fclose(pie);
    insert_img(f, "pie_risks.gif");
    }
@@ -1017,15 +1066,31 @@ static int make_index(hosts)
  
    float risks_f[5];
    char * lbl[] = {"Low", "Medium", "Serious", "High"};
-   int expl [] = {0,0,0,20};
-   unsigned long   clr[] = {  0xFFFF80L, 0x80FF80L, 0xFF80FFL, 0xFF4040L};
-   float total;
+   int expl [] = {0,0,0,0};
+   unsigned long   clr[] = { 0x80FF80L, 0xFFFF80L,  0xFF80FFL, 0xFF4040L};
    FILE * pie;
+   int num_risks = 0;
+   int i;
    
-  
    risk_severity(hosts, risks_f);
-   total = risks_f[0] + risks_f[1] + risks_f[2] + risks_f[3];  
-   if(total)
+   for(i=0;i<4;i++)
+   {
+    if(risks_f[i] == 0)
+    {
+     int j;
+     for(j=i;j<3;j++)
+     {
+     risks_f[j] = risks_f[j + 1];
+     lbl[j] = lbl[j + 1];
+     clr[j] = clr[j + 1];
+     }
+    }
+    else num_risks ++;
+   }
+   
+   expl[num_risks-1] = 20;
+   
+   if(num_risks)
    {			
     pie = fopen("pie_risks.gif", "wb");
     GDCPIE_title = "Security Risks";
@@ -1040,7 +1105,7 @@ static int make_index(hosts)
     GDCPIE_EdgeColor = 0x000000L;
     GDCPIE_missing = NULL;
     GDCPIE_percent_labels = GDCPIE_PCT_RIGHT;
-    pie_gif(480, 360, pie, GDC_3DPIE, 4, lbl, risks_f);
+    pie_gif(480, 360, pie, GDC_3DPIE, num_risks, lbl, risks_f);
     fclose(pie);
     insert_img(f, "pie_risks.gif");
     }
@@ -1224,7 +1289,7 @@ static int make_index(hosts)
      fprintf(f, "<a href=\"%s/index.html\">%s</a></td>\n", name, hosts->name);
      if(holes)fprintf(f, "<td><FONT COLOR=\"#FF0000\">(<b>found %d security hole%s)</b></FONT></td>\n",
  					holes, holes>1?"s":"");
-     else if(warnings)fprintf(f, "<td><FONT COLOR=\"#FF0000\">(<b>found %d security warning%s</b>)</FONT></td>\n",
+     else if(warnings)fprintf(f, "<td><FONT COLOR=\"#660000\">(<b>found %d security warning%s</b>)</FONT></td>\n",
  					warnings, warnings>1?"s":"");
      else if(notes)fprintf(f, "<td>(<b>found %d security note%s</b>)</td>\n",
  					notes, notes>1?"s":"");
