@@ -511,7 +511,7 @@ void summary_to_file(FILE *file, struct arglist *hosts)
  fprintf(file, "<tbody><tr><td>\n");
  fprintf(file, "    <table border=0 cellpadding=2 cellspacing=1 width=\"100%%\">\n   <tbody>\n");
  fprintf(file, "    <tr>\n\t<td class=title colspan=2>Scan Details</td></tr>\n");
- fprintf(file, "    <tr>\n\t<td class=default width=\"60%%\">Hosts which where alive and responding during test</td>\n");
+ fprintf(file, "    <tr>\n\t<td class=default width=\"60%%\">Hosts which were alive and responding during test</td>\n");
  fprintf(file, "\t<td class=default width=\"30%%\">%d</td></tr>\n",
                                 arglist_length(hosts));
 
