@@ -367,8 +367,6 @@ monitor_add_host(ctrls,hostname,port)
  GtkWidget * box, * hbox;
  GtkStyle  * style;
  GtkWidget * pixmapwid;
- GdkPixmap * pixmap = NULL;
- GdkBitmap * mask;
  GList * dlist;
  GtkWidget * window = arg_get_value(ctrls,"WINDOW");
 
@@ -397,10 +395,7 @@ monitor_add_host(ctrls,hostname,port)
  if(F_show_pixmaps)
  {
   style = gtk_widget_get_style(window);
- pixmap = gdk_pixmap_create_from_xpm_d(window->window, &mask,
-					&style->bg[GTK_STATE_NORMAL],
-					(char **)computer_xpm);
- pixmapwid = gtk_pixmap_new(pixmap, mask); 
+  pixmapwid = make_pixmap(window, &style->bg[GTK_STATE_NORMAL], (gchar**)computer_xpm);
  
  gtk_box_pack_start(GTK_BOX(box), pixmapwid, FALSE, FALSE, 0);
  gtk_widget_show(pixmapwid);
@@ -422,7 +417,7 @@ monitor_add_host(ctrls,hostname,port)
  gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 0);
  gtk_widget_show(label);
  
- label = gtk_label_new("Attack : ");
+ label = gtk_label_new("Checks : ");
  gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 0);
  gtk_widget_show(label);
  
@@ -474,8 +469,6 @@ monitor_add_host(ctrls,hostname,port)
  gtk_object_set_data(GTK_OBJECT(item), "progress_bar_portscan", progress_bar_portscan);
  gtk_widget_show(table);
  gtk_widget_show(item);
- if(pixmap)
-  gtk_object_set_data(GTK_OBJECT(item), "pixmap", pixmap);
  dlist = g_list_append(dlist, item);
  gtk_object_set_data(GTK_OBJECT(arg_get_value(ctrls, "LIST")), hostname,item);
  gtk_list_append_items(GTK_LIST(arg_get_value(ctrls, "LIST")), dlist);
