@@ -533,7 +533,7 @@ Please launch nessus-mkrand(1) first !");
 	}
 
 #ifdef CLN_AUTH_SRV
-      if (paranoia_level == 1 || paranoia_level == 3)
+      if (DontCheckServerCert == 0 && (paranoia_level == 1 || paranoia_level == 3))
 	{
 	  X509	*cert = SSL_get_peer_certificate(ssl);
 	  char	stored_hash[SHA_DIGEST_LENGTH];
@@ -779,6 +779,8 @@ int main(int argc, char * argv[])
   /*
    * Version check
    */
+   
+ 
 
   if(version_check(NESSUS_VERSION, nessuslib_version())>0)
   {
@@ -964,6 +966,7 @@ you have deleted older versions nessus libraries from your system\n",
     display_help("nessus");
     exit(1);
    }
+  F_quiet_mode = 1;
   be = backend_import_report(inf);
   if(be >= 0)
   {
@@ -987,7 +990,7 @@ you have deleted older versions nessus libraries from your system\n",
    	backend_to_nsr(be, outf);
    else if(!strcmp(type, "html"))
    	arglist_to_html(backend_convert(be), outf);
-   else if(!strcmp(type, "html_pie"))
+   else if(!strcmp(type, "html_pie") || !strcmp(type, "html_graph"))
    	arglist_to_html_graph(backend_convert(be), outf);
    else if(!strcmp(type, "nbe"))
    	backend_to_nbe(be, outf);
@@ -1008,7 +1011,7 @@ you have deleted older versions nessus libraries from your system\n",
    fprintf(stderr, "Could not import '%s' - is it a .nsr or .nbe file ?\n",
    		inf);		
   }
-   
+  exit(0);
  }
 
  if(!gui)F_quiet_mode = 1;
