@@ -278,8 +278,9 @@ plugin_info_window_setup(res, pluginname)
  
 
  char * category;
- char * buf;
+ char buf[4096];
  struct arglist * plugin;
+ char * txt;
  
  
  plugin = arg_get_value(res, pluginname);
@@ -290,7 +291,7 @@ plugin_info_window_setup(res, pluginname)
 #endif
   return;
  }
- buf = emalloc(4095);
+
  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 #if GTK_VERSION > 10
  gtk_window_set_default_size(GTK_WINDOW(window), 400,500);
@@ -330,6 +331,37 @@ plugin_info_window_setup(res, pluginname)
  gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE,0);
  gtk_widget_show(label);
  
+ txt = arg_get_value(plugin, "CVE_ID");
+ if( txt != NULL && txt[0] != '\0' )
+ {
+ snprintf(buf, sizeof(buf), "CVE : %s", txt);
+ label = gtk_label_new(buf);
+ gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE,0);
+ gtk_widget_show(label);
+ }
+ 
+ txt = arg_get_value(plugin, "BUGTRAQ_ID");
+ if( txt != NULL  && txt[0] != '\0' )
+ {
+ snprintf(buf, sizeof(buf), "Bugtraq ID : %s", txt);
+ label = gtk_label_new(buf);
+ gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE,0);
+ gtk_widget_show(label);
+ }
+ 
+ 
+ txt = arg_get_value(plugin, "XREFS");
+ if( txt != NULL  && txt[0] != '\0' )
+ {
+ snprintf(buf, sizeof(buf), "Other references : %s", txt);
+ label = gtk_label_new(buf);
+ gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE,0);
+ gtk_widget_show(label);
+ }
+ 
+ 
+ 
+ 
  label = gtk_label_new(arg_get_value(plugin, "VERSION"));
  gtk_box_pack_start(GTK_BOX(box), label, FALSE,FALSE,0);
  gtk_widget_show(label);
@@ -413,6 +445,5 @@ plugin_info_window_setup(res, pluginname)
  gtk_widget_show(box);
  gtk_widget_show(window);
   
- efree(&buf);
 }
 #endif
