@@ -1,10 +1,10 @@
 /* Nessus
- * Copyright (C) 1998 Renaud Deraison
+ * Copyright (C) 1998 - 2001 Renaud Deraison
+ *
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 2,
+ * as published by the Free Software Foundation
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,6 +15,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  */
 
 #include <includes.h>
@@ -65,7 +75,7 @@ prefs_dialog_about(window)
  gtk_widget_show(hr);
  }
 
- label = gtk_label_new("Nessus "NESSUS_VERSION"\nCopyright (C) 1998, 1999, 2000 : ");
+ label = gtk_label_new("Nessus "NESSUS_VERSION"\nCopyright (C) 1998 - 2003 : ");
  gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 10);
  gtk_widget_show(label);
  
@@ -81,28 +91,20 @@ prefs_dialog_about(window)
  gtk_table_attach(GTK_TABLE(table), label,1,2,0,1, GTK_FILL|GTK_EXPAND,1,1,1);
  gtk_widget_show(label);
  
- label = gtk_label_new("Cipher layer : ");
+ label = gtk_label_new("SSL Support : ");
  gtk_table_attach(GTK_TABLE(table), label, 0,1,1,2, GTK_FILL|GTK_EXPAND,1,1,1);
  gtk_widget_show(label);
  
- label = gtk_label_new("Jordan Hrycaj");
+ label = gtk_label_new("Michel Arboi");
  gtk_table_attach(GTK_TABLE(table), label,1,2,1,2, GTK_FILL|GTK_EXPAND,1,1,1);
  gtk_widget_show(label);
  
- label = gtk_label_new("Contributions : ");
+  label = gtk_label_new("Pie/Charts library : ");
  gtk_table_attach(GTK_TABLE(table), label, 0,1,2,3, GTK_FILL|GTK_EXPAND,1,1,1);
  gtk_widget_show(label);
  
- label = gtk_label_new("Jochen Wiedmann, Christoph Puppe");
- gtk_table_attach(GTK_TABLE(table), label,1,2,2,3, GTK_FILL|GTK_EXPAND,1,1,1);
- gtk_widget_show(label);
- 
-  label = gtk_label_new("Pie/Charts library : ");
- gtk_table_attach(GTK_TABLE(table), label, 0,1,3,4, GTK_FILL|GTK_EXPAND,1,1,1);
- gtk_widget_show(label);
- 
  label = gtk_label_new("Bruce Verderaime");
- gtk_table_attach(GTK_TABLE(table), label,1,2,3,4, GTK_FILL|GTK_EXPAND,1,1,1);
+ gtk_table_attach(GTK_TABLE(table), label,1,2,2,3, GTK_FILL|GTK_EXPAND,1,1,1);
  gtk_widget_show(label);
  
  
