@@ -231,7 +231,7 @@ prefs_dialog_setup(widget, preferences)
 
  cancel = gtk_button_new_with_label("Quit");
  gtk_signal_connect(GTK_OBJECT(cancel), "clicked",
- 	GTK_SIGNAL_FUNC(nessus_exit), NULL);
+ 	GTK_SIGNAL_FUNC(close_display), NULL);
  gtk_box_pack_end(GTK_BOX(hbox), cancel,TRUE, TRUE, 0);
  gtk_widget_show(cancel);
  
@@ -988,7 +988,7 @@ a scan in the 'nessusd' section");
   }
   
   
-  if(!strlen(hostname))
+  if( hostname == NULL || hostname[0] == '\0' )
   { 
    show_error("You must enter the name of the primary target\n\
 to attack in the 'target' section");
