@@ -16,6 +16,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  */
  
  
@@ -52,12 +62,7 @@ static char *
 get_username
   (void)
 {
-# ifdef ENABLE_CRYPTO_LAYER
-  static char *user;
-  if (user == 0)
-    user = peks_get_username ();
-  return user;
-# else
+  /*ENABLE_CRYPTO_LAYER*/
   char * user;
   struct passwd * pwd;
   /* Look up the user's name. */
@@ -73,7 +78,6 @@ get_username
   if (pwd && pwd->pw_name)
     return pwd->pw_name;
   return "";
-# endif
 }
 
 struct arglist * prefs_dialog_auth(window)
@@ -104,11 +108,8 @@ struct arglist * prefs_dialog_auth(window)
   /*
    * Set up the table which will contain everything
    */
-#ifdef ENABLE_CRYPTO_LAYER
-  table = gtk_table_new(7, 2, TRUE);
-#else
+   /*ENABLE_CRYPTO_LAYER*/
   table = gtk_table_new(6, 2, TRUE);
-#endif /* ENABLE_CRYPTO_LAYER */
   gtk_container_add(GTK_CONTAINER (frame), table);
   gtk_container_border_width(GTK_CONTAINER(table), 10);
   gtk_widget_show(table);
@@ -120,9 +121,6 @@ struct arglist * prefs_dialog_auth(window)
     (GTK_ENTRY(entry), default_server? default_server:DEFAULT_SERVER);
 # endif /* DEFAULT_SERVER */
   arg_add_value(ctrls, "HOSTNAME", ARG_PTR, -1, entry);
-#else  /* USE_AF_INET */
-  entry = gtk_label_new("(this is AF_UNIX)");
-#endif /* USE_AF_INET */
   gtk_table_attach_defaults(GTK_TABLE(table), entry, 1,2,0,1);
   gtk_widget_show(entry);
   
@@ -133,63 +131,35 @@ struct arglist * prefs_dialog_auth(window)
   gtk_box_pack_end(GTK_BOX(box), label, FALSE, FALSE,0);
   gtk_widget_show(label);
   
-#ifdef USE_AF_INET
   entry = gtk_entry_new();
   {
    char tbuf[10];
-   sprintf (tbuf, "%d", DEFAULT_PORT);
+   sprintf (tbuf, "%d", NESIANA_PORT);
    gtk_entry_set_text (GTK_ENTRY(entry), tbuf);
    arg_add_value(ctrls, "PORT", ARG_PTR, -1, entry);
   }
-#else  /* USE_AF_INET */
-  entry = gtk_label_new("(this is AF_UNIX)");
-#endif /* USE_AF_INET */
   gtk_table_attach_defaults(GTK_TABLE(table), entry, 1,2,1,2);
   gtk_widget_show(entry);
 
-#ifdef ENABLE_CRYPTO_LAYER
-  box = gtk_hbox_new(FALSE,0);
-  gtk_table_attach_defaults(GTK_TABLE(table), box, 0,1,2,3);
-  gtk_widget_show(box);
-  label = gtk_label_new("Encryption : ");
-  gtk_box_pack_end(GTK_BOX(box), label, FALSE, FALSE,0);
-  gtk_widget_show(label);
-  
-  entry = gtk_entry_new();
-  gtk_entry_set_text(GTK_ENTRY(entry), DEFAULT_CIPHER);
-  arg_add_value(ctrls, "CIPHER", ARG_PTR, -1, entry);
-  gtk_table_attach_defaults(GTK_TABLE(table), entry, 1,2,2,3);
-  gtk_widget_show(entry);
-#endif /* ENABLE_CRYPTO_LAYER */
-
   separator = gtk_hseparator_new();
-#ifdef ENABLE_CRYPTO_LAYER
-  gtk_table_attach_defaults(GTK_TABLE(table), separator, 0,2,3,4);
-#else
   gtk_table_attach_defaults(GTK_TABLE(table), separator, 0,2,2,3);
-#endif /* ENABLE_CRYPTO_LAYER */
   gtk_widget_show(separator);
+#endif /* AF_INET */
   
   entry = gtk_entry_new();
   gtk_entry_set_text (GTK_ENTRY(entry), default_user?default_user:get_username ());
   
-#ifdef ENABLE_CRYPTO_LAYER
-  gtk_table_attach_defaults(GTK_TABLE(table), entry, 1,2,4,5);
-#else
+  /*ENABLE_CRYPTO_LAYER*/
   gtk_table_attach_defaults(GTK_TABLE(table), entry, 1,2,3,4);
-#endif /* ENABLE_CRYPTO_LAYER */
   arg_add_value(ctrls, "USERNAME", ARG_PTR, -1, entry);
   gtk_widget_show(entry);
   
   box = gtk_hbox_new(FALSE,0);
- #ifdef ENABLE_CRYPTO_LAYER
-  gtk_table_attach_defaults(GTK_TABLE(table), box, 0,1,5,6);
-#else
+  /*ENABLE_CRYPTO_LAYER*/
   gtk_table_attach_defaults(GTK_TABLE(table), box, 0,1,4,5);
-#endif
   gtk_widget_show(box);
   
-#ifndef ENABLE_CRYPTO_LAYER
+  /*ENABLE_CRYPTO_LAYER*/
   label = gtk_label_new("Password : ");
   gtk_box_pack_end(GTK_BOX(box), label, FALSE, FALSE,0);
   gtk_widget_show(label);
@@ -199,16 +169,11 @@ struct arglist * prefs_dialog_auth(window)
   gtk_table_attach_defaults(GTK_TABLE(table), entry, 1,2,4,5);
   arg_add_value(ctrls, "PASSWORD", ARG_PTR, -1, entry);
   gtk_widget_show(entry);
-#endif /* ENABLE_CRYPTO_LAYER */
-
 
   button = gtk_button_new_with_label("Log in");
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-#ifdef ENABLE_CRYPTO_LAYER
-  gtk_table_attach(GTK_TABLE(table), button, 1,2,7,8,GTK_FILL | GTK_EXPAND,0,10,10);
-#else
+  /*ENABLE_CRYPTO_LAYER*/
   gtk_table_attach(GTK_TABLE(table), button, 1,2,6,7,GTK_FILL | GTK_EXPAND,0,10,10);
-#endif /* ENABLE_CRYPTO_LAYER */
   arg_add_value(ctrls, "BUTTON_LOG_IN", ARG_PTR, -1, button);
   gtk_signal_connect /*_object*/(GTK_OBJECT (button), "clicked",
  			   (GtkSignalFunc)prefs_dialog_login_callback,
@@ -219,11 +184,8 @@ struct arglist * prefs_dialog_auth(window)
   
   button = gtk_button_new_with_label(" Log out");
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-#ifdef ENABLE_CRYPTO_LAYER
+  /*ENABLE_CRYPTO_LAYER*/
   gtk_table_attach(GTK_TABLE(table), button, 1,2,7,8,GTK_FILL | GTK_EXPAND,0,10,10);
-#else
-  gtk_table_attach(GTK_TABLE(table), button, 1,2,6,7,GTK_FILL | GTK_EXPAND,0,10,10);
-#endif /* ENABLE_CRYPTO_LAYER */
   arg_add_value(ctrls, "BUTTON_LOG_OUT", ARG_PTR, -1, button);
   gtk_signal_connect /*_object*/(GTK_OBJECT (button), "clicked",
  			   (GtkSignalFunc)prefs_dialog_logout_callback,
@@ -232,11 +194,8 @@ struct arglist * prefs_dialog_auth(window)
 
   
   label = gtk_label_new(" Connected");
-#ifdef ENABLE_CRYPTO_LAYER
-  gtk_table_attach(GTK_TABLE(table), label, 0,1,6,7, GTK_FILL | GTK_EXPAND, 0,10,10);
-#else
+  /*ENABLE_CRYPTO_LAYER*/
   gtk_table_attach(GTK_TABLE(table), label, 0,1,5,6, GTK_FILL | GTK_EXPAND, 0,10,10);
-#endif /* ENABLE_CRYPTO_LAYER */
   arg_add_value(ctrls, "CONNECTED", ARG_PTR, -1, label);
   
   box = gtk_hbox_new(FALSE,5);
@@ -244,27 +203,29 @@ struct arglist * prefs_dialog_auth(window)
   gtk_widget_show(box);
  
   gtk_widget_realize(window);
+
   if(F_show_pixmaps)
   {
   style = gtk_widget_get_style(frame);
+#ifdef USE_AF_INET
   pixmap = gdk_pixmap_create_from_xpm_d(window->window, &mask,
 					&style->bg[GTK_STATE_NORMAL],
 					(gchar **)computer_xpm);             
   pixmapwid = gtk_pixmap_new(pixmap, mask);			   
   gtk_box_pack_start(GTK_BOX(box), pixmapwid, FALSE,FALSE,0);
   gtk_widget_show(pixmapwid);	
+#endif
   }
   
+#ifdef USE_AF_INET
   label = gtk_label_new("Nessusd Host : ");
   gtk_box_pack_end(GTK_BOX(box), label,FALSE,FALSE,0);
   gtk_widget_show(label);
+#endif
   
   box = gtk_hbox_new(FALSE,0);
-#ifdef ENABLE_CRYPTO_LAYER
-  gtk_table_attach_defaults(GTK_TABLE(table), box, 0,1,4,5);
-#else
+  /*ENABLE_CRYPTO_LAYER*/
   gtk_table_attach_defaults(GTK_TABLE(table), box, 0,1,3,4);
-#endif /* ENABLE_CRYPTO_LAYER */
   gtk_widget_show(box);
   
   if(F_show_pixmaps)
@@ -307,9 +268,6 @@ static int prefs_dialog_login_callback(w, ctrls)
 #endif
  char * t;
  char * err;
-#ifdef ENABLE_CRYPTO_LAYER 
- int hostkey = 0;
-#endif 
 #ifdef USE_AF_INET
  t = gtk_entry_get_text(GTK_ENTRY(arg_get_value(ctrls, "HOSTNAME")));
  if((!t) ||(!strlen(t)))
@@ -340,7 +298,7 @@ static int prefs_dialog_login_callback(w, ctrls)
     }
   username = emalloc(strlen(t)+1);
   strncpy(username, t, strlen(t));
-#ifndef ENABLE_CRYPTO_LAYER
+  /*ENABLE_CRYPTO_LAYER*/
   t = gtk_entry_get_text(GTK_ENTRY(arg_get_value(ctrls, "PASSWORD")));
   if((!t) ||(!strlen(t)))
     {
@@ -349,45 +307,20 @@ static int prefs_dialog_login_callback(w, ctrls)
     }
   password = emalloc(strlen(t)+1);
   strncpy(password, t, strlen(t));
-#endif
 
 #ifdef USE_AF_INET
-#ifdef ENABLE_CRYPTO_LAYER
-  t = gtk_entry_get_text(GTK_ENTRY(arg_get_value(ctrls, "CIPHER")));
-  if (t != 0 && strcasecmp (t, "none") == 0)
-    t = 0 ;
-  if (t != 0 && find_classes_by_name (0, 0, t) < 0) {
-    show_error("Unsupported encryption type");
-    return (1) ;
-  }
-  stored_pwd = password;
-  
-tryagain: 
-  err = connect_to_nessusd(hostname, port, username, t);
-#else
+  /*ENABLE_CRYPTO_LAYER*/
   err = connect_to_nessusd(hostname, port, username, password);
-#endif /* ENABLE_CRYPTO_LAYER */
 #else
   err = connect_to_nessusd("localhost", -1, username, password);
 #endif
   if(err){
-  	/* XXX fixme because I'm ugly ! */
-        if(!strcmp(err, "Host key for that server has been saved"))
-	{
-#ifdef ENABLE_CRYPTO_LAYER
-         show_info(err);
-  	 if(!hostkey)
-	 {
-	  hostkey++;
-	  goto tryagain;
-	 }
-#endif
-	}
-	else
+	  /*ENABLE_CRYPTO_LAYER*/
 	  show_error(err);
 	}
  else
  {
+   /*ENABLE_CRYPTO_LAYER*/
  gtk_widget_hide(arg_get_value(ctrls, "BUTTON_LOG_IN"));
  gtk_widget_show(arg_get_value(ctrls, "BUTTON_LOG_OUT"));
  gtk_widget_show(arg_get_value(ctrls, "CONNECTED"));
