@@ -15,6 +15,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  */
 
 #include <includes.h>
@@ -26,93 +36,12 @@
 #include "../preferences.h"
 #include "../password_dialog.h"
 #include "globals.h"
-#include "splash_screen.h"
 #include "error_dialog.h"
 static int add_rule_callback(GtkWidget *, struct arglist *);
 static void sigh_button_event(GtkWidget *, GdkEventButton *, struct arglist *);
 
 
-#ifdef ENABLE_CRYPTO_LAYER
-extern peks_key  * key; 
-extern unsigned keylen;
-extern char        *kf;
-typedef char*(*peks_get_pwd_t)(int);
-extern peks_get_pwd_t peks_get_pwd;
 
-static void keyring_peks_callback(const char *);
-static GtkWidget * keyring_menu;
-static void 
-dialog_change_passphrase()
-{
- if (!created_private_key () &&
-	peks_save_private_key (0, key, kf, peks_get_pwd) < 0)        
-	{
-	char * error = emalloc(40 + strlen(peks_strerr(errno)));
-        sprintf(error, "%s - aborting.", peks_strerr(errno));
-        show_error(error);
-        free(error);
-	}
-}	    
-
-
-static void
-keyring_peks_callback(nm)
-const char * nm;
-{
- char * orig = (char*)strdup(nm);
- char * name = orig;
- GtkWidget * item;
- if(!keyring_menu)
-  return;
- while(name[0]==' ')name++;
- while(name[strlen(name)-1]=='\n')name[strlen(name)-1]='\0';
- item = gtk_menu_item_new_with_label(name);
- gtk_object_set_data(GTK_OBJECT(item), "name", strdup(name));
- gtk_menu_append(GTK_MENU(keyring_menu), item);
- free(orig);
- gtk_widget_show(item);
-}
-
-
-static GtkWidget * 
-dialog_keyring()
-{
- GtkWidget *menu;
- 
-  menu = gtk_option_menu_new();
-  keyring_menu = gtk_menu_new();
-  gtk_option_menu_set_menu(GTK_OPTION_MENU(menu), keyring_menu);
-  peks_list_keyfile (keyring_peks_callback, kf);
-  return menu;
-}
-
-void
-dialog_delete_key(w, menu)
- GtkWidget * w, *menu;
-{
- GtkWidget * active = gtk_menu_get_active(GTK_MENU(menu));
- char * name = gtk_object_get_data(GTK_OBJECT(active), "name");
- char * t;
- char * error;
- if(!name)
-  return;
- 
- gtk_widget_hide(active);
- t = strstr(name, " - ");
- if(t)t[0] = '\0';
- if (strchr (name, '@') != 0) { /* syntax is: usr@host */
-      if (peks_delete_userkey (name, kf, peks_get_pwd) < 0) goto error ;
-    } else
-      if (peks_delete_hostkey (name, kf, peks_get_pwd) < 0) goto error ;
-  return;
-error :
-    error = emalloc(40 + strlen(peks_strerr(errno)));
-    sprintf(error, "%s - aborting.", peks_strerr(errno));
-    show_error(error);
-    free(error);
-}
-
-#endif
 
  
 struct arglist * prefs_dialog_user(prefs)
@@ -126,10 +55,7 @@ struct arglist * prefs_dialog_user(prefs)
  GtkWidget * entry;
  GtkWidget * list;
  GtkWidget * s_window;
-#ifdef ENABLE_CRYPTO_LAYER 
- GtkWidget * sep;
- GtkWidget * k;
-#endif 
+ /*ENABLE_CRYPTO_LAYER*/
  frame = gtk_frame_new("User");
  gtk_container_border_width(GTK_CONTAINER(frame), 10);
  gtk_widget_show(frame);
@@ -141,37 +67,7 @@ struct arglist * prefs_dialog_user(prefs)
  gtk_container_add(GTK_CONTAINER(frame), table);
  gtk_container_border_width(GTK_CONTAINER(table), 10);
  gtk_widget_show(table);
-#ifdef ENABLE_CRYPTO_LAYER
- label = gtk_label_new("Key management : ");
- gtk_table_attach(GTK_TABLE(table), label, 0,1,0,1, GTK_FILL | GTK_EXPAND, 0,0,0);
- gtk_widget_show(label);
- 
- button = gtk_button_new_with_label("Change passphrase");
- gtk_table_attach(GTK_TABLE(table), button, 0,3,1,2, GTK_FILL | GTK_EXPAND, 0,0,0);
- gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (dialog_change_passphrase), NULL);
- gtk_widget_show(button);
- 
- 
- label = gtk_label_new("Keyring : ");
- gtk_table_attach(GTK_TABLE(table), label, 0,1,2,3, GTK_FILL | GTK_EXPAND, 0,10,10);
- gtk_widget_show(label);
- 
- k = dialog_keyring();
- gtk_table_attach(GTK_TABLE(table), k, 1,2,2,3, GTK_FILL|GTK_EXPAND, 0,10,10);
- gtk_widget_show(k);
- 
- button = gtk_button_new_with_label("Delete key");
- gtk_table_attach(GTK_TABLE(table), button, 2,3,2,3, GTK_FILL|GTK_EXPAND, 0,10,10);
- gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (dialog_delete_key), keyring_menu);
- gtk_widget_show(button);
- 
- sep = gtk_hseparator_new();
- gtk_table_attach(GTK_TABLE(table), sep, 0,3,3,4, GTK_FILL|GTK_EXPAND, 0,10,10);
- gtk_widget_show(sep);
-#endif 
- 
+ /*ENABLE_CRYPTO_LAYER*/
  label = gtk_label_new("Rules : ");
  gtk_table_attach(GTK_TABLE(table), label, 0,1,4,5, GTK_FILL | GTK_EXPAND, 0,0,0);
  gtk_widget_show(label);
