@@ -105,18 +105,12 @@ static GtkWidget *
 warning_sign(w)
  GtkWidget * w;
 {
- GdkPixmap * pm;
  GtkStyle * style;
- GdkBitmap * mask;
  GtkWidget * p;
  GtkWidget * ret;
  
  style = gtk_widget_get_style(w);
- pm = gdk_pixmap_create_from_xpm_d(w->window,
- 				     &mask,
-				     &style->bg[GTK_STATE_NORMAL],
-				     (gchar**)warning_small_xpm);
- p = gtk_pixmap_new(pm, mask);
+ p = make_pixmap(w, &style->bg[GTK_STATE_NORMAL], warning_small_xpm);
  
  ret = gtk_button_new();
  gtk_widget_set_usize(ret, 20, 20);
