@@ -95,7 +95,7 @@ char * target_file_to_list(filename)
    efree (&text);
    return 0;
  }
- len = sb.st_size;
+ len = (int)sb.st_size;
  ret = emalloc (len) ;
  offs =   0 ;
  left = len ;
