@@ -212,7 +212,12 @@ launch_plugin(globals, plugins, hostname, cur_plug, num_plugs, hostinfos, key, n
 		return 0;
 		}
 		
-   comm_send_status(globals, hostname, "attack", (*cur_plug)++, num_plugs);
+   if ( comm_send_status(globals, hostname, "attack", (*cur_plug)++, num_plugs) < 0 )
+   {
+    /* Could not send our status back to our father -> exit */
+    pluginlaunch_stop();
+    return ERR_HOST_DEAD;
+   }
 
 
     if(save_kb(globals))
@@ -398,6 +403,18 @@ attack_host      (globals,
    for(;;)
    {
     struct arglist * plugin;
+    pid_t parent;
+    
+    /*
+     * Check that our father is still alive 
+     */
+    parent = getppid();
+    if(parent <= 1 || process_alive(parent) == 0 )
+    {
+     pluginlaunch_stop();
+     return;
+    }
+     
     plugin = plugins_scheduler_next(sched);
     if(plugin != NULL && plugin != PLUG_RUNNING)
     { 
@@ -487,7 +504,6 @@ attack_start(args)
  /*
   * Options regarding the communication with our father
   */
- set_linger(thread_socket, 60);
  nessus_deregister_connection((int)arg_get_value(globals, "global_socket"));
  arg_set_value(globals, "global_socket", -1, (void*)thread_socket);
  
@@ -516,9 +532,9 @@ attack_start(args)
   }
   log_write("Finished testing %s. Time : %ld.%.2ld secs\n",
   		hostname,
-  		now.tv_sec - then.tv_sec,
-		(now.tv_usec - then.tv_usec) / 10000);
-  shutdown(soc, 2);
+  		(long)(now.tv_sec - then.tv_sec),
+		(long)((now.tv_usec - then.tv_usec) / 10000));
+  shutdown(soc, 2);		
   close(soc);
 }
 
@@ -659,13 +675,13 @@ start_attack_network:
   
   
   hg_flags = preferences_get_host_expansion(preferences);
-  max_hosts = get_max_hosts_number(preferences);
+  max_hosts = get_max_hosts_number(globals, preferences);
   
   
   if( restoring == 0)
   {
-  int max_checks  = get_max_checks_number(preferences);
-  log_write("user %s starts a new attack. Target(s) : %s, with max_hosts = %d and max_checks = %d\n",
+  int max_checks  = get_max_checks_number(globals, preferences);
+  log_write("user %s starts a new scan. Target(s) : %s, with max_hosts = %d and max_checks = %d\n",
 			 attack_user_name(globals), 
 			 hostlist,
 			 max_hosts, 
@@ -673,7 +689,7 @@ start_attack_network:
   }
   else
   {
-   int max_checks  = get_max_checks_number(preferences);
+   int max_checks  = get_max_checks_number(globals, preferences);
    log_write("user %s restores session %s, with max_hosts = %d and max_checks = %d\n",
    			attack_user_name(globals),
 			(char*)arg_get_value(globals, "RESTORE-SESSION-KEY"),
@@ -687,14 +703,15 @@ start_attack_network:
   /* 
    * Initialize the hosts_gatherer library 
    */
-   			  
+  if ( preferences_get_slice_network_addresses ( preferences ) != 0 )
+  	hg_flags |= HG_DISTRIBUTE;
+				  
   hg_globals = hg_init(hostlist, hg_flags);
   hg_res = hg_next_host(hg_globals, &host_ip, hostname, sizeof(hostname));
   if( tested != NULL )
    while(hg_res >= 0 && 
          harg_get_int( tested, hostname ) != 0 )
 	 		{
-	 		efree(&hostname);
 			hg_res = hg_next_host(hg_globals, &host_ip, hostname, sizeof(hostname));
 			}
 			
@@ -727,6 +744,11 @@ start_attack_network:
       		 attack_user_name(globals), 
 		 hostname);
       hg_res = hg_next_host(hg_globals, &host_ip, hostname, sizeof(hostname));
+      if( tested != NULL )
+      {
+        while(hg_res >= 0 &&  harg_get_int( tested, hostname ) != 0 )
+	 		hg_res = hg_next_host(hg_globals, &host_ip, hostname, sizeof(hostname));
+      }			
       continue;
      }
    }
@@ -739,6 +761,11 @@ start_attack_network:
      			attack_user_name(globals), 
 			hostname);
      hg_res = hg_next_host(hg_globals, &host_ip, hostname, sizeof(hostname));
+     if( tested != NULL )
+      {
+        while(hg_res >= 0 &&  harg_get_int( tested, hostname ) != 0 )
+	 		hg_res = hg_next_host(hg_globals, &host_ip, hostname, sizeof(hostname));
+      }	
      continue;
     }
    }
@@ -767,6 +794,11 @@ start_attack_network:
 	 {
 	  /* remote host is down */
 	  hg_res = hg_next_host(hg_globals, &host_ip, hostname, sizeof(hostname));
+	  if( tested != NULL )
+	  {
+   		while(hg_res >= 0 && harg_get_int( tested, hostname ) != 0 )
+	 		hg_res = hg_next_host(hg_globals, &host_ip, hostname, sizeof(hostname));
+	  }		
 	  continue;
 	 }
 	}
