@@ -69,7 +69,11 @@ extract_extensions(caps, banner)
  if(!t)
   return;
  
- t+=2;
+ t++;
+ if ( *t == '\0' ) return;
+ t++;
+ if ( *t == '\0' ) return;
+
  
  for(;;)
  {
@@ -104,6 +108,9 @@ extract_extensions(caps, banner)
    */
   else if(!strcmp(t, "plugins_bugtraq_id"))
    caps->plugins_bugtraq_id = 1;
+   
+  else if(!strcmp(t, "plugins_xrefs"))
+   caps->plugins_xrefs = 1; 
  
   /*
    * We send timestamps to the client
@@ -312,6 +319,14 @@ send_plug_info(globals, plugins)
        strcat(str, " <|> ");
        strcat(str, bid);
      }
+     
+     if(caps->plugins_xrefs)
+     {
+       char * xref = plug_get_xref(args);
+       if(xref == NULL)xref = "NOXREF";
+       strcat(str, " <|> ");
+       strcat(str, xref);
+     }
 	
 		  
       auth_printf(globals, "%s\n", str);	
