@@ -262,6 +262,9 @@ static int nes_thread(args)
  int i;
  plugin_run_t func;
 
+ if(preferences_benice(NULL))nice(-5);
+
+
  /* XXX ugly hack */
  arg_set_value(globals, "global_socket", sizeof(int), (void*)soc2);
  for(i=4;i<256;i++)
@@ -269,8 +272,41 @@ static int nes_thread(args)
   if( ( i != soc )  && (i != soc2 ) )
     close(i);
  }
+ 
+ #ifdef RLIMIT_RSS
+ {
+ struct rlimit rlim;
+ getrlimit(RLIMIT_RSS, &rlim);
+ rlim.rlim_cur = 1024*1024*40;
+ rlim.rlim_max = 1024*1024*40;
+ setrlimit(RLIMIT_RSS, &rlim);
+ }
+#endif
+
+#ifdef RLIMIT_AS
+ {
+ struct rlimit rlim;
+ getrlimit(RLIMIT_AS, &rlim);
+ rlim.rlim_cur = 1024*1024*40;
+ rlim.rlim_max = 1024*1024*40;
+ setrlimit(RLIMIT_AS, &rlim);
+ }
+#endif
+
+#ifdef RLIMIT_DATA
+ {
+ struct rlimit rlim;
+ getrlimit(RLIMIT_DATA, &rlim);
+ rlim.rlim_cur = 1024*1024*40;
+ rlim.rlim_max = 1024*1024*40;
+ setrlimit(RLIMIT_DATA, &rlim);
+ }
+#endif
+
+
  setproctitle("testing %s (%s)", (char*)arg_get_value(arg_get_value(args, "HOSTNAME"), "NAME"), (char*)arg_get_value(args, "name"));
  func = arg_get_value(args, "func");
+ signal(SIGTERM, _exit);
  return func(args);
 }
 
