@@ -25,7 +25,7 @@
  * file, but you are not obligated to do so.  If you do not wish to
  * do so, delete this exception statement from your version.
  *
- * $Id: nessusd.c,v 1.213 2003/05/22 13:11:05 renaud Exp $
+ * $Id: nessusd.c,v 1.223 2003/07/04 20:55:55 renaud Exp $
  */
 
 #include <includes.h>
@@ -66,14 +66,12 @@ int allow_severity = LOG_NOTICE;
 #include "utils.h"
 #include "corevers.h"
 #include "pluginlaunch.h"
+#include "hosts_gatherer.h"
 
 #ifdef HAVE_SSL
 #include <openssl/err.h>
 #endif
 
-#ifdef DEBUG
-int single_shot = 0 ;
-#endif
 
 #ifndef HAVE_SETSID
 #define setsid() setpgrp()
@@ -110,6 +108,73 @@ static void server_thread (struct arglist *);
 
 
 
+static struct in_addr * convert_ip_addresses(char * ips)
+{
+ char * t;
+ struct in_addr addr;
+ struct in_addr * ret;
+ int num = 0;
+ int num_allocated = 256;
+ char * orig;
+ 
+ ips = orig = estrdup(ips);
+ 
+ ret = emalloc((num_allocated + 1) * sizeof(struct in_addr));
+ 
+ 
+ while ( ( t = strchr(ips, ',')) != NULL )
+ {
+  t[0] = '\0';
+  while (ips[0] == ' ')ips ++;
+  if( inet_aton(ips, &addr) ==  0) 
+  {
+   fprintf(stderr, "Could not convert %s\n", ips);
+  }
+  else
+  {
+   ret[num] = addr;
+   num ++;
+  }
+  
+  if( num >= num_allocated )
+  {
+   num_allocated *= 2;
+   ret = erealloc(ret, (num_allocated + 1) * sizeof(struct in_addr));
+  }
+  
+  ips = t + 1;
+ }
+ 
+ while(ips[0] == ' ')ips++;
+ 
+ if( inet_aton(ips, &addr) ==  0) 
+  {
+   fprintf(stderr, "Could not convert %s\n", ips);
+  }
+  else {
+   ret[num] = addr;
+   num ++;
+   }
+  if( num >= num_allocated )
+  {
+   num_allocated ++;
+   ret = erealloc(ret, (num_allocated + 1) * sizeof(struct in_addr));
+  }
+ 
+ 
+ 
+ ret[num].s_addr = 0;
+ ret = erealloc(ret, ( num + 1 ) * sizeof(struct in_addr));
+ efree(&orig);
+ return ret;
+} 
+  
+  
+  
+
+
+
+
 static void
 dump_cfg_specs
   (struct arglist *prefs)
@@ -143,10 +208,6 @@ start_daemon_mode
   char *s;
   int fd;
 
-# ifdef DEBUG
-  if (single_shot)
-    return ;
-# endif
 
   /* do not block the listener port for sub sequent servers */
   close (g_iana_socket);
@@ -206,10 +267,6 @@ static void
 end_daemon_mode
   (void)
 {
-# ifdef DEBUG
-  if (single_shot)
-    return ;
-# endif
 
   /* clean up all processes the process group */
   make_em_die (SIGTERM);
@@ -299,7 +356,10 @@ server_thread(globals)
 
  *x509_dname = '\0';
  
-if(preferences_benice(prefs))nice(10);
+ /*
+  * Everyone runs with a nicelevel of 10
+  */
+if(preferences_benice(prefs))nice(10); 
   	
  nessus_signal(SIGCHLD, sighand_chld);
 #if 1
@@ -409,6 +469,7 @@ if(preferences_benice(prefs))nice(10);
  }
   else {
      char * uhome ;
+     char * phome;
    efree(&asciiaddr);
    if(perms){
      	rules_add(&rules, &perms, NULL);
@@ -421,9 +482,11 @@ if(preferences_benice(prefs))nice(10);
    }
    
    uhome = user_home(globals);
-  
-   store_init_user(uhome);
+   phome = emalloc(strlen(uhome) + strlen("plugins") + 2);
+   sprintf(phome, "%s/plugins", uhome);
+   store_init_user(phome);
    efree(&uhome);
+   efree(&phome);
    plugins = plugins_reload_user(globals, prefs, plugins);
 
    arg_set_value(globals, "plugins", -1, plugins);
@@ -724,13 +787,18 @@ main_loop()
 #ifdef USE_AF_INET
       asciiaddr = estrdup(inet_ntoa(address.sin_addr));
 #ifdef USE_LIBWRAP      
-      if(!(hosts_ctl("nessusd", STRING_UNKNOWN, asciiaddr, STRING_UNKNOWN)))
+      {
+       char host_name[1024];
+        
+      hg_get_name_from_ip(address.sin_addr, host_name, sizeof(host_name));
+      if(!(hosts_ctl("nessusd", host_name, asciiaddr, STRING_UNKNOWN)))
       {
        shutdown(soc, 2);
        close(soc);
        log_write("Connection from %s rejected by libwrap", asciiaddr);
        continue;
       }
+      }
 #endif      
       log_write("connection from %s\n", (char *)asciiaddr);
 #else
@@ -751,6 +819,9 @@ main_loop()
        */
       globals = emalloc(sizeof(struct arglist));
       arg_add_value(globals, "global_socket", ARG_INT, -1, (void *)soc);
+     
+
+      
    
 #ifdef USE_FORK_THREADS
       my_plugins = g_plugins;
@@ -961,11 +1032,12 @@ display_help
 {
 #ifdef USE_AF_INET
   printf("nessusd, version %s\n", NESSUS_VERSION);
-  printf("\nusage : nessusd [-vcphdDLC] [-a address]\n\n");
+  printf("\nusage : nessusd [-vcphdDLC] [-a address] [ -S <ip[,ip,...]> ]\n\n");
 #else
   printf("\nusage : nessusd [-vchdD]\n\n");
 #endif /*def USE_AF_INET */
   printf("\ta <address>    : listen on <address>\n");
+  printf("\tS <ip[,ip,...]>: send packets with a source IP of <ip[,ip...]>\n");
   printf("\tv              : shows version number\n");
   printf("\th              : shows this help\n");
 #ifdef USE_AF_INET
@@ -987,6 +1059,7 @@ main(int argc, char * argv[], char * envp[])
   char * myself;
   int do_fork = 0;
   struct in_addr addr; 
+  struct in_addr * src_addrs = NULL;
   struct arglist * options = emalloc(sizeof(struct arglist));
   int print_specs = 0;
   int i;
@@ -1069,11 +1142,12 @@ you have deleted older versions of libnasl from your system\n",
       {"port",           required_argument, 0, 'p'}, 
       {"config-file",    required_argument, 0, 'c'}, 
       {"gen-config",           no_argument, 0, 'g'}, 
+      {"src-ip",	 required_argument, 0, 'S'},
       {0, 0, 0, 0}
     };
 
     if ((i = getopt_long 
-	 (argc, argv, "Dhvgc:dsa:p:", 
+	 (argc, argv, "Dhvgc:dsa:p:S:", 
 	  long_options, &option_index)) == EOF) break;
     else
       switch(i)
@@ -1130,6 +1204,11 @@ you have deleted older versions of libnasl from your system\n",
 	  strncpy(config_file, optarg, strlen(optarg));
 	  arg_add_value (options, "acc_hint", ARG_INT, sizeof(int), (void*)1);
 	  break;
+       case 'S':
+	  if( optarg == NULL ) { display_help(myself); EXIT(0); }
+	  src_addrs = (struct in_addr* )convert_ip_addresses(optarg);
+	  socket_source_init(src_addrs);
+	  break;
        case 'd' :
            printf("This is Nessus %s for %s %s\n", NESSUS_VERSION, NESS_OS_NAME, NESS_OS_VERSION);
            printf("compiled with %s\n", NESS_COMPILER);
@@ -1170,6 +1249,9 @@ you have deleted older versions of libnasl from your system\n",
 #endif
 
 	   printf("\tRunning as euid                : %d\n", geteuid());
+#ifdef USE_LIBWRAP
+	   printf("\tCompiled with tcpwrappers support\n");
+#endif
            printf("\n\nInclude these infos in your bug reports\n");
 	   DO_EXIT(0);
 	   break;
@@ -1203,9 +1285,6 @@ you have deleted older versions of libnasl from your system\n",
 
   arg_add_value(options, "iana_port", ARG_INT, sizeof(int), (void *)iana_port);
   arg_add_value(options, "config_file", ARG_STRING, strlen(config_file), config_file);
-
-  arg_add_value(options, "config_file", ARG_STRING, strlen(config_file), 
-  		config_file);
   arg_add_value(options, "addr", ARG_PTR, -1, &addr);
   
   init_nessusd (options, 1, exit_early /* stop early ? */);
