@@ -538,7 +538,7 @@ ntp_11_recv_file(globals)
   * remote socket.
   */
   
-  fd = open(localname, O_CREAT|O_WRONLY, 0600);
+  fd = open(localname, O_CREAT|O_WRONLY|O_TRUNC, 0600);
   if(fd < 0)
   {
    perror("ntp_11_recv_file: open() ");
@@ -775,6 +775,8 @@ __ntp_1x_timestamp_scan_host(globals, msg, host)
   t = time(NULL);
   tmp = ctime(&t);
   strncpy(timestr, tmp, sizeof(timestr) - 1);
+  if( timestr[strlen(timestr) - 1 ] == '\n' )
+	   timestr[strlen(timestr) - 1 ] = '\0';
   auth_printf(globals, "SERVER <|> TIME <|> %s <|> %s <|> %s <|> SERVER\n",
   				msg,
 				host, 
