@@ -19,6 +19,18 @@
 #ifndef _NESSUSD_NTP_11_H
 #define _NESSUSD_NTP_11_H
 
-int ntp_11_parse_input(struct arglist *, char *);
+#define NTP_STOP_WHOLE_TEST 2
 
+int ntp_11_parse_input(struct arglist *, char *);
+void ntp_11_show_end(struct arglist *, char *);
+
+
+
+int ntp_1x_timestamp_host_scan_starts(struct arglist*, char*);
+int ntp_1x_timestamp_host_scan_ends(struct arglist*, char*);
+int ntp_1x_timestamp_host_scan_interrupted(struct arglist*, char*);
+
+int ntp_1x_timestamp_scan_starts(struct arglist*);
+int ntp_1x_timestamp_scan_ends(struct arglist*);
+int ntp_1x_send_dependencies(struct arglist*);
 #endif
