@@ -6,7 +6,7 @@ char * requirements_plugin(struct arglist *,
 			   struct arglist *);
  
 
-int  requirements_common_ports(struct arglist *,
+struct arglist*  requirements_common_ports(struct arglist *,
 			       struct arglist *);
 			       
 #endif			  
