@@ -84,7 +84,7 @@ int preferences_new(char * name)
  fprintf(fd, "# Maximum number of simultaneous checks against each host tested : \n");
  fprintf(fd, "max_checks = 10\n\n");
  fprintf(fd, "# Niceness. If set to 'yes', nessusd will renice itself to 10.\n");
- fprintf(fd, "be_nice = yes\n\n");
+ fprintf(fd, "be_nice = no\n\n");
 
  fprintf(fd, "# Log file (or 'syslog') : \n");
  fprintf(fd, "logfile = %s\n\n", NESSUSD_MESSAGES);
@@ -109,7 +109,6 @@ int preferences_new(char * name)
  fprintf(fd, "# Language of the plugins :\n");
  fprintf(fd, "language = %s\n\n", NESSUSD_LANGUAGE);
 
- /*ENABLE_CRYPTO_LAYER*/
  fprintf(fd, "\n\n# Optimization : \n");
  fprintf(fd, "# Read timeout for the sockets of the tests : \n");
  fprintf(fd, "checks_read_timeout = 5\n");
@@ -127,7 +126,7 @@ int preferences_new(char * name)
  
  fprintf(fd, "\n\n#--- Knowledge base saving (can be configured by the client) :\n");
  fprintf(fd, "# Save the knowledge base on disk : \n");
- fprintf(fd, "save_knowledge_base = yes\n");
+ fprintf(fd, "save_knowledge_base = no\n");
  fprintf(fd, "# Restore the KB for each test :\n");
  fprintf(fd, "kb_restore = no\n");
  fprintf(fd, "# Only test hosts whose KB we do not have :\n");
@@ -148,6 +147,12 @@ int preferences_new(char * name)
  fprintf(fd, "# Name of the user who can remotely update the plugins\n");
  fprintf(fd, "admin_user = root\n");
  
+ fprintf(fd, "\n\n");
+ fprintf(fd, "# If this option is set, Nessus will not scan a network incrementally\n");
+ fprintf(fd, "# (10.0.0.1, then 10.0.0.2, 10.0.0.3 and so on..) but will attempt to\n");
+ fprintf(fd, "# slice the workload throughout the whole network (ie: it will scan\n");
+ fprintf(fd, "# 10.0.0.1, then 10.0.0.127, then 10.0.0.2, then 10.0.0.128 and so on...\n");
+ fprintf(fd, "slice_network_addresses = no\n");
  fprintf(fd, "#end.\n");
  
  
@@ -285,6 +290,22 @@ int preferences_get_host_expansion(preferences)
  return ret;
 }
 
+int preferences_get_slice_network_addresses(preferences)
+ struct arglist * preferences;
+{
+ char * str;
+ 
+ if( preferences == NULL )
+ 	return 0;
+	
+ str  = arg_get_value(preferences, "slice_network_addresses");
+ if( str == NULL ) 
+ 	return 0;
+	
+ return strcmp(str, "yes" ) == 0;
+}
+
+
 int preferences_get_checks_read_timeout(preferences)
  struct arglist *preferences;
 {
@@ -471,10 +492,9 @@ preferences_benice(preferences)
  char * pref;
  static int yes = -1;
  
- if(!preferences)
+ if( preferences == NULL )
   {
-   yes = -1;
-   return -1;
+   return yes;
   }
   
   
@@ -485,7 +505,7 @@ preferences_benice(preferences)
  if(pref && !strcmp(pref, "yes"))
  	 yes = 1;
  else
- 	 yes = -1;
+ 	 yes = 0;
 
  return yes;
 }
