@@ -1,10 +1,10 @@
 /* Nessus
- * Copyright (C) 2000 Renaud Deraison
+ * Copyright (C) 1998 - 2001  Renaud Deraison
+ *
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 2,
+ * as published by the Free Software Foundation
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,6 +15,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  *
  * save_kb :
  *  save the knowledge base about a remote host
@@ -24,14 +34,12 @@
 #include <includes.h>
 #include "log.h"
 #include "comm.h"
+#include "users.h"
+#include "locks.h"
 #ifdef ENABLE_SAVE_KB
 
 
 
-#ifndef O_SYNC
-#define O_SYNC 0
-#endif
-
 #ifndef MAP_FAILED
 #define MAP_FAILED (void*)(-1)
 #endif
@@ -47,98 +55,6 @@
 			
 ===========================================================================*/
 
-static char * 
-file_lock_name(name)
- char*name;
-{
- char * ret = emalloc(strlen(name) + 6);
- char * t;
- 
- name = strdup(name);
- t = strrchr(name, '/');
- if(t)
- {
-  t[0] = '\0';
-  sprintf(ret, "%s/.%s.lck", name, t+1);
-  t[0] = '/';
- }
- else sprintf(ret, ".%s.lck", name);
- 
- efree(&name);
- return ret;
-}
- 
-static int 
-file_lock(name)
- char * name;
-{
- char * lock = file_lock_name(name);
- int fd = -1;
- char buf[20];
- fd = open(lock, O_RDWR|O_CREAT|O_EXCL, 0600);
- efree(&lock);
- if(fd < 0)
-  return -1;
- 
- bzero(buf, sizeof(buf));
- sprintf(buf, "%d", getpid());
- write(fd, buf, strlen(buf));
- close(fd);
- return 0;
-}
-
-static int 
-file_unlock(name)
- char * name;
-{
- char * lock = file_lock_name(name);
- int e = 0;
-
- e = unlink(lock);
- efree(&lock);
- return e;
-}
-
-static int
-file_locked(name)
- char * name;
-{
- struct stat st;
- int e;
- char * lock = file_lock_name(name);
- char asc_pid[20];
- int pid;
- int ret = 0;
- int fd = open(lock, O_RDONLY);
- if(fd < 0)
- {
-  efree(&lock);
-  return 0;
- }
- 
- 
- /*
-  * We check that the process which set the
-  * lock is still alive
-  */
- bzero(asc_pid, sizeof(asc_pid));
- read(fd, asc_pid, sizeof(asc_pid)-1);
- close(fd);
- pid = atoi(asc_pid);
- if(process_alive(pid))
- {
-  log_write("The file %s is locked by process %d. Delete %s if you think this is incorrect\n",
-  		name,
-		pid,
-		lock);
-  ret = 1;		
- }
- else
-  file_unlock(name);
-  
- efree(&lock);
- return ret;
-}
 static char *
 filter_odd_name(name)
  char * name;
@@ -167,9 +83,10 @@ static char *
 kb_dirname(globals)
  struct arglist * globals;
 {
- char * dir,  * user = arg_get_value(globals,"user");
- dir = emalloc(strlen(NESSUSD_STATEDIR) + strlen(user) + strlen("kbs") + 3);
- sprintf(dir, "%s/%s/kbs", NESSUSD_STATEDIR, user);
+ char * home = user_home(globals);
+ char * dir  = emalloc(strlen(home) + strlen("kbs") + 2);
+ sprintf(dir, "%s/kbs", home);
+ efree(&home);
  return(dir);
 }
 
@@ -187,7 +104,7 @@ kb_mkdir(dir)
  char * dir;
 {
  char *t;
- int e;
+ int ret = 0;
  
  dir = estrdup(dir);
  t = strchr(dir+1, '/');
@@ -198,9 +115,16 @@ kb_mkdir(dir)
   t[0] = '/';
   t = strchr(t+1, '/');
  }
- mkdir(dir, 0700);
+ 
+ 
+ if ((ret = mkdir(dir, 0700)) < 0) {
+  if(errno != EEXIST)
+    log_write("mkdir(%s) failed : %s\n", dir, strerror(errno));
+  efree(&dir);
+  return ret;
+ }
  efree(&dir);
- return 0;
+ return ret;
 }
 
 
@@ -228,8 +152,9 @@ kb_fname(globals, hostname)
  return ret;
 }
 
+
 /*
- * mmap() tends sometimes act weirdly
+ * mmap() tends to sometimes act weirdly
  */
 
 static char*
@@ -239,42 +164,170 @@ map_file(file)
  struct stat st;
  char *ret;
  int i = 0;
+ int len;
  
  bzero(&st, sizeof(st));
  fstat(file, &st);
- if(!st.st_size)
+ len = (int)st.st_size;
+ if( len == 0 )
  	return NULL;
 	
  lseek(file, 0, SEEK_SET);
- ret = emalloc(st.st_size);
- while(i != st.st_size)
+ ret = emalloc(len + 1);
+ while( i < len )
  {
-  int e = read(file, ret, st.st_size);
+  int e = read(file, ret + i, len - i);
   if(e > 0)
   	i+=e;
    else
      {
-     	log_write("read(%d, buf, %d) failed : %s\n", file, st.st_size, strerror(errno));
+     	log_write("read(%d, buf, %d) failed : %s\n", file, len, strerror(errno));
 	efree(&ret);
-	lseek(file, st.st_size, SEEK_SET);
+	lseek(file, len, SEEK_SET);
 	return NULL;
      }
  }
- lseek(file, st.st_size, SEEK_SET);
+ 
+ lseek(file, len, SEEK_SET);
  return ret;
 }
+ 
+static int
+save_kb_entry_present_already(globals, hostname, name, value)
+ struct arglist * globals;
+ char * hostname;
+ char * name;
+ char * value;
+{
+  char * buf;
+  harglst * kbs;
+  int fd;
+  char* req;
+  int ret;
+   
+  kbs = arg_get_value(globals, "save_kb");
+  if(!kbs)
+   return -1;
+  
+  fd = harg_get_int(kbs, hostname);
+  if(fd <= 0)
+   return -1;
+ 
+  buf = map_file(fd);
+  if(buf)
+  {
+   req = emalloc(strlen(name) + strlen(value) + 2);
+   sprintf(req, "%s=%s",name, value);
+   if(strstr(buf, req))
+    ret = 1;
+   else
+    ret = 0;
+   efree(&buf);
+   efree(&req);
+   return ret;
+  }
+ return -1;
+} 
+ 
+static int
+save_kb_rm_entry_value(globals, hostname, name, value)
+ struct arglist * globals;
+ char * hostname;
+ char * name;
+ char * value;
+{
+  char * buf;
+  char * t;
+  harglst * kbs;
+  int fd;
+  char * req;
+  
+   
+  kbs = arg_get_value(globals, "save_kb");
+  if(!kbs)
+   return -1;
+  
+  fd = harg_get_int(kbs, hostname);
+  if(fd <= 0)
+   return -1;
+  
+  buf = map_file(fd);
+  if(buf)
+  {
+   if(value)
+   { 
+    req = emalloc(strlen(name) + strlen(value) + 2);
+    sprintf(req, "%s=%s", name, value);
+   }
+   else 
+    req = estrdup(name);
+    
+   t = strstr(buf, req);
+   if(t)
+   {
+    char * end;
+       
+     while(t[0] != '\n')
+     {
+       if(t == buf)break;
+       else t--;
+     }
+       
+     if(t[0] == '\n')t++;
+     end = strchr(t, '\n');
+     t[0] = '\0';
+     if(end){
+       	end[0] = '\0';
+	end++;
+	}
 
+     if((lseek(fd, 0, SEEK_SET))<0)
+       {
+        log_write("lseek() failed - %s\n", strerror(errno));
+       }
+       
+     if((ftruncate(fd, 0))<0)
+       {
+        log_write("ftruncate() failed - %s\n", strerror(errno));
+       }
+       
+      
+     if(write(fd, buf, strlen(buf)) < 0)
+       {
+        log_write("write() failed - %s\n", strerror(errno));
+       }
+     
+     if(end){
+       	if((write(fd, end, strlen(end)))<0)
+	  log_write("write() failed - %s\n", strerror(errno));
+	}
+      }
+      efree(&buf);
+      efree(&req);
+      lseek(fd, 0, SEEK_END);
+     }
+     return 0;
+}
 
+static int
+save_kb_rm_entry(globals, hostname, name)
+ struct arglist * globals;
+ char * hostname;
+ char * name;
+{
+ return save_kb_rm_entry_value(globals, hostname, name, NULL);
+}
+ 
 /*
  * Write data
  *
  * We want to avoid duplicates for :
  *
- * 	Successful/*
- *	SentData/*
- *	Launched/*
+ * 	Successful/...
+ *	SentData/...
+ *	Launched/...
  *
- * We don't want to save /tmp/*
+ * We don't want to save /tmp/...
  */	
 static int
 save_kb_write(globals, hostname, name, value, type)
@@ -286,6 +339,7 @@ save_kb_write(globals, hostname, name, value, type)
  int fd;
  char * str;
  int e;
+ struct timeval now;
 
  if(!globals  ||
     !hostname || 
@@ -302,7 +356,7 @@ save_kb_write(globals, hostname, name, value, type)
  fd = harg_get_int(kbs, hostname);
  if(fd <= 0)
   {
-  log_write("user %s : Can not find KB fd for %s\n", arg_get_value(globals, "user"), hostname);
+  log_write("user %s : Can not find KB fd for %s\n", (char*)arg_get_value(globals, "user"), hostname);
   return -1;
   }
  
@@ -310,7 +364,9 @@ save_kb_write(globals, hostname, name, value, type)
  /*
   * Don't save temporary KB entries
   */
- if(!strncmp(name, "/tmp/", 4))
+ if(!strncmp(name, "/tmp/", 4) ||
+    !strncmp(name, "/NIDS/", 6) ||
+    !strncmp(name, "/Settings/", 10))
    	return 0;
 
 
@@ -321,61 +377,23 @@ save_kb_write(globals, hostname, name, value, type)
     !strncmp(name, "Launched/", strlen("Launched/")) ||
     !strncmp(name, "SentData/", strlen("SentData/")))
     {
-     char * buf;
-     char * t;
-   
-     buf = map_file(fd);
-     if(buf)
-     {
-      t = strstr(buf, name);
-      if(t)
-      {
-       long offset = (long)((long)t - (long)buf);
-       char * end;
-       
-       t-=2;
-       end = strchr(t, '\n');
-       t[0] = '\0';
-       if(end){
-       	end[0] = '\0';
-	end++;
-	}
-
-       if((lseek(fd, 0, SEEK_SET))<0)
-       {
-        log_write("lseek() failed - %s\n", strerror(errno));
-       }
-       
-       if((ftruncate(fd, 0))<0)
-       {
-        log_write("ftruncate() failed - %s\n", strerror(errno));
-       }
-       
-      
-       if(write(fd, buf, strlen(buf)) < 0)
-       {
-        log_write("write() failed - %s\n", strerror(errno));
-       }
-     
-       if(end){
-       
-       	if((write(fd, end, strlen(end)))<0)
-	  log_write("write() failed - %s\n", strerror(errno));
-	}
-      }
-      efree(&buf);
-     }
+     save_kb_rm_entry(globals, hostname, name);
     }
+ 
+ if(save_kb_entry_present_already(globals, hostname, name, value))
+ {
+  save_kb_rm_entry_value(globals, hostname, name, value);
+ }
    
- str = emalloc(strlen(name) + strlen(value) + 5);
- sprintf(str, "%d %s=%s\n", type, name, value);
+ str = emalloc(strlen(name) + strlen(value) + 25);
+ gettimeofday(&now, NULL);
+ sprintf(str, "%ld %d %s=%s\n", (long)now.tv_sec, type, name, value);
  e = write(fd, str, strlen(str));
  if(e < 0)
  {
-  log_write("user %s : write kb error - %s\n", arg_get_value(globals, "user"), strerror(errno));
+  log_write("user %s : write kb error - %s\n", (char*)arg_get_value(globals, "user"), strerror(errno));
  }
  efree(&str);
- fsync(fd);
  return 0;
 }
 
@@ -410,8 +428,6 @@ save_kb_new(globals, hostname)
  char * user = arg_get_value(globals, "user");
  int ret = 0;
  int f;
- struct timeval tv;
- char * str;
  harglst * kbs;
  
  if(!hostname)return -1;
@@ -427,7 +443,7 @@ save_kb_new(globals, hostname)
   return 0;
  }
  unlink(fname); /* delete the previous kb */
- f = open(fname, O_CREAT|O_RDWR|O_EXCL|O_SYNC, 0600);
+ f = open(fname, O_CREAT|O_RDWR|O_EXCL, 0640);
  if(f < 0)
  {
   log_write("user %s : Can not save KB for %s - %s", user, hostname, strerror(errno));
@@ -448,23 +464,10 @@ save_kb_new(globals, hostname)
    }
    
   if(harg_get_int(kbs, hostname)>0)
-   {
    harg_set_int(kbs, hostname, f);
-   }
   else
    harg_add_int(kbs, hostname, f);
  }
- 
- /*
-  * Add the time of day as the first line of the file
-  */
- bzero(&tv, sizeof(tv));
- gettimeofday(&tv, NULL);
- 
- str = emalloc(60);
- sprintf(str, "%ld\n", tv.tv_sec);
- write(f, str, strlen(str));
- efree(&str);
  return 0;
 }
 
@@ -493,10 +496,9 @@ save_kb_close(globals, hostname)
  * (returns true if a knowledge base exists)
  */
 int
-save_kb_exists(globals, hostname, max_age)
+save_kb_exists(globals, hostname)
  struct arglist * globals;
  char * hostname;
- long max_age; /* in seconds */
 {
  char * fname = kb_fname(globals, hostname);
  FILE *f;
@@ -508,37 +510,11 @@ save_kb_exists(globals, hostname, max_age)
  }
  f = fopen(fname, "r");
  efree(&fname);
- if(!f)return 0;
- else 
-  {
-   char buf[256];
-   long age;
-   struct timeval tv;
-   long now;
-   
-   gettimeofday(&tv, NULL);
-   now = tv.tv_sec;
-   
-   bzero(buf, sizeof(buf));
-   fgets(buf, sizeof(buf) - 1, f);
-   age = atol(buf);
-   fclose(f);
-   
-   if(!max_age)return 1;
-   
-   /* test for the age */
-   if((now - age) > max_age)
-   		{
-   		log_write("user %s : KB for %s is outdated of %ld seconds (max age : %ld)\n",
-				arg_get_value(globals, "user"),
-				hostname,
-				now - age,
-				max_age);
-			
-   		return 0;
-		}
-   else return 1;
-  }
+ if(!f) return 0;
+ else {
+ 	fclose(f);
+ 	return 1;
+      }
 }
 
 
@@ -547,7 +523,12 @@ save_kb_write_str(globals, hostname, name, value)
  struct arglist * globals;
  char * hostname, * name, * value;
 {
- return save_kb_write(globals, hostname, name, value, ARG_STRING);
+ char * newvalue  = addslashes(value);
+ int e;
+ 
+ e = save_kb_write(globals, hostname, name, newvalue, ARG_STRING);
+ efree(&newvalue);
+ return e;
 }
 
 
@@ -557,14 +538,116 @@ save_kb_write_int(globals, hostname, name, value)
  char * hostname, * name;
  int value;
 {
- char * asc_value = emalloc(25);
+ static char asc_value[25];
  int e;
  sprintf(asc_value, "%d", value);
  e = save_kb_write(globals, hostname, name, asc_value, ARG_INT);
- efree(&asc_value);
+ bzero(asc_value, sizeof(asc_value));
  return e;
 }
 
+
+
+
+
+/*
+ * Restores a copy of the knowledge base
+ */
+int
+save_kb_restore_backup(globals, hostname)
+ struct arglist * globals;
+ char*hostname;
+{
+ char * fname = kb_fname(globals, hostname);
+ char * bakname;
+ int fd;
+ 
+ bakname = emalloc(strlen(fname) + 5);
+ strcat(bakname, fname);
+ strcat(bakname, ".bak");
+ 
+ unlink(fname);
+ if((fd = open(bakname, O_RDONLY)) >= 0)
+ {
+  close(fd);
+  rename(bakname, fname);
+ }
+ return 0;
+}
+/*
+ * Makes a copy of the knowledge base
+ */
+
+int
+save_kb_backup(globals, hostname)
+ struct arglist * globals;
+ char* hostname;
+{
+ char * fname = kb_fname(globals, hostname);
+ char * newname = NULL;
+ int fd_src = -1, fd_dst = -1;
+ 
+ 
+ if(file_locked(fname))
+  {
+   log_write("%s is locked\n", fname);
+   goto failed1;
+  }
+ 
+ file_lock(fname);
+ 
+ newname = emalloc(strlen(fname) + 5);
+ strcat(newname, fname);
+ strcat(newname, ".bak");
+ 
+ if((fd_src = open(fname, O_RDONLY)) >= 0)
+ {
+  char buf[4096];
+  int n;
+  fd_dst = open(newname, O_WRONLY|O_CREAT|O_TRUNC, 0640);
+  if(fd_dst < 0)
+  { 
+   log_write("save_kb_backup failed : %s", strerror(errno));
+   close(fd_src);
+   goto failed;
+  }
+  bzero(buf, sizeof(buf));
+  while((n = read(fd_src, buf, sizeof(buf))) > 0)
+  {
+   int m = 0;
+   while(m != n)
+   {
+    int e = write(fd_dst, &(buf[m]), n-m);
+    if(e < 0)
+     {
+     log_write("save_kb_backup failed : %s", strerror(errno));
+     close(fd_src);
+     close(fd_dst);
+     goto failed;
+     }
+     m+=e;
+    } 
+    bzero(buf, sizeof(buf));
+   }
+  }
+  else 
+    log_write("save_kb_backup failed : %s\n", strerror(errno));
+    
+  close(fd_src);
+  close(fd_dst);
+  efree(&newname);
+  file_unlock(fname);
+  efree(&fname);
+  return 0;
+failed:
+  file_unlock(fname);
+failed1:  
+  efree(&fname);
+  efree(&newname);
+  return -1;
+}
+
+
 /*
  * Restores a previously saved knowledge base
  *
@@ -579,9 +662,10 @@ save_kb_load_kb(globals, hostname)
  char * fname = kb_fname(globals, hostname);
  FILE * f;
  int fd;
- struct arglist * ret;
+ struct arglist * ret, * arg;
  char buf[4096];
  harglst * kbs;
+ long max_age = save_kb_max_age(globals);
  
  if(file_locked(fname))
  {
@@ -591,7 +675,7 @@ save_kb_load_kb(globals, hostname)
  f = fopen(fname, "r");
  if(!f)
   {
-   log_write("user %s : Could not open %s - kb won't be restored for %s\n", arg_get_value(globals, "user"), fname, hostname);
+   log_write("user %s : Could not open %s - kb won't be restored for %s\n", (char*)arg_get_value(globals, "user"), fname, hostname);
    efree(&fname);
    return NULL;
   }
@@ -608,14 +692,20 @@ save_kb_load_kb(globals, hostname)
  {
   int type;
   char * name, * value, *t;
+  struct timeval then, now;
   
   buf[strlen(buf)-1]='\0'; /* chomp(buf) */
   t = strchr(buf, ' ');
-  
   if(!t)continue;
   
   t[0] = '\0';
-  type = atoi(buf);
+  
+  then.tv_sec = atol(buf);
+  t[0] = ' ';t++;
+  type = atoi(t);
+  t = strchr(t, ' ');
+  if(!t)
+	  continue;
   t[0] = ' ';t++;
   name = t;
   t = strchr(name, '=');
@@ -626,12 +716,42 @@ save_kb_load_kb(globals, hostname)
   t++;
   value = strdup(t);
   
-  if(strcmp(name, "Host/dead") && strncmp(name, "/tmp/", 4))
+  if(strcmp(name, "Host/dead") && strncmp(name, "/tmp/", 4) &&
+     strcmp(name, "Host/ping_failed"))
   {
-  if(type == ARG_STRING)
-   arg_add_value(ret, name, ARG_STRING, strlen(value), strdup(value));
-  else if(type == ARG_INT)
-   arg_add_value(ret, name, ARG_INT, sizeof(int), (void*)atoi(value));
+   gettimeofday(&now, NULL);
+   if(now.tv_sec - then.tv_sec > max_age)
+   {
+    /* 
+    log_write("discarding %s because it's too old\n",
+    		name,
+    		(now.tv_sec - then.tv_sec));
+     */		
+   }
+   else
+   {
+    if((!strncmp(name, "Services/", 9)) && (arg_get_type(ret, name) > 0))
+    {
+     if(arg_get_type(ret, name)==ARG_ARGLIST)
+      arg = arg_get_value(ret, name);
+     else {
+      /* log_write("arglist for %s\n",name); */
+      arg = emalloc(sizeof(struct arglist));
+      arg_add_value(arg, name, arg_get_type(ret, name), -1, arg_get_value(ret, name));
+      arg_set_value(ret, name, -1, arg);
+      arg_set_type(ret, name, ARG_ARGLIST);
+     }
+    }
+    else arg = ret;
+    if(type == ARG_STRING)
+    {
+     char * tmp = rmslashes(value);
+     arg_add_value(arg, name, ARG_STRING, strlen(tmp), tmp);
+    }
+    else 
+     if(type == ARG_INT)
+      arg_add_value(arg, name, ARG_INT, sizeof(int), (void*)atoi(value));
+   }
   } 
   efree(&value);
   efree(&name);
@@ -640,12 +760,13 @@ save_kb_load_kb(globals, hostname)
  fclose(f);
  
  /*
-  * Re-open the file, but in append-mode now
+  * Re-open the file
   */
- fd = open(fname, O_APPEND|O_SYNC|O_RDWR);
+ fd = open(fname, O_RDWR);
  efree(&fname);
  if(fd > 0)
  {
+  lseek(fd, 0, SEEK_END);
   if(arg_get_value(globals, "save_kb"))
     kbs = arg_get_value(globals, "save_kb");
   else
@@ -664,7 +785,7 @@ save_kb_load_kb(globals, hostname)
   else
    harg_add_int(kbs, hostname, fd);
  }
- else log_write("user %s : ERROR - %s\n", arg_get_value(globals, "user"), strerror(errno));
+ else log_write("user %s : ERROR - %s\n", (char*)arg_get_value(globals, "user"), strerror(errno));
  return ret;
 }
 
@@ -680,9 +801,16 @@ save_kb_load_kb(globals, hostname)
 int save_kb(globals)
  struct arglist * globals;
 {
- struct arglist * preferences = arg_get_value(globals, "preferences");
+ struct arglist * preferences;
  char * value;
  
+ if(!globals)
+  return 0;
+  
+ preferences = arg_get_value(globals, "preferences");
+ if(!preferences)
+  return 0;
+  
  value = arg_get_value(preferences, "save_knowledge_base");
  
  if(value && !strcmp(value, "yes"))
@@ -758,12 +886,16 @@ int save_kb_replay_check(globals, type)
   case ACT_GATHER_INFO:
   	name = "kb_dont_replay_info_gathering";
 	break;
+  case ACT_MIXED_ATTACK:
+  case ACT_DESTRUCTIVE_ATTACK:
   case ACT_ATTACK:
   	name = "kb_dont_replay_attacks";
 	break;
   case ACT_DENIAL:
+  case ACT_KILL_HOST:
   	name = "kb_dont_replay_denials";
 	break;
+  /* ACT_SETTINGS and ACT_INIT should always be executed */
  }
  
  if(name)
@@ -797,7 +929,7 @@ save_kb_max_age(globals)
  *
  * The idea of a differential scan is to only show the user what
  * has changed in the report. To do this, libnessus relies on the content
- * of the Success/* and Failures/* KB entries that record if a test 
+ * of the Success/... and Failures/... KB entries that record if a test 
  * was sucessful or failed in the past.
  *
  * Note that the KB now contain the full text of the messages sent 
@@ -824,10 +956,10 @@ diff_scan(globals)
 
 
 void
-diff_scan_enable(plugin)
- struct arglist * plugin;
+diff_scan_enable(pluginargs)
+ struct arglist * pluginargs;
 {
- arg_add_value(arg_get_value(plugin, "plugin_args"), "DIFF_SCAN", ARG_INT, sizeof(int), (void*)1);
+ arg_add_value(pluginargs, "DIFF_SCAN", ARG_INT, sizeof(int), (void*)1);
 }
 
 #endif
