@@ -1,10 +1,10 @@
 /* Nessus
- * Copyright (C) 2000 Renaud Deraison
+ * Copyright (C) 1998 - 2001 Renaud Deraison
+ *
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 2,
+ * as published by the Free Software Foundation
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,6 +15,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * In addition, as a special exception, Renaud Deraison
+ * gives permission to link the code of this program with any
+ * version of the OpenSSL library which is distributed under a
+ * license identical to that listed in the included COPYING.OpenSSL
+ * file, and distribute linked combinations including the two.
+ * You must obey the GNU General Public License in all respects
+ * for all of the code used other than OpenSSL.  If you modify
+ * this file, you may extend this exception to your version of the
+ * file, but you are not obligated to do so.  If you do not wish to
+ * do so, delete this exception statement from your version.
  *
  * save_tests :
  *  save the tests in real time, allowing the user a safe
@@ -25,10 +35,9 @@
 #include <includes.h>
 #include "log.h"
 #include "comm.h"
+#include "users.h"
+#include "locks.h"
 #ifdef ENABLE_SAVE_TESTS
-#ifndef O_SYNC 
-#define O_SYNC 0
-#endif
 
 #include "save_tests.h"
 
@@ -38,105 +47,6 @@
 
  =================================================================*/
  
-/*
- * File locking operations
- */
-static char * 
-file_lock_name(name)
- char*name;
-{
- char * ret = emalloc(strlen(name) + 6);
- char * t;
- 
- name = strdup(name);
- t = strrchr(name, '/');
- if(t)
- {
-  t[0] = '\0';
-  sprintf(ret, "%s/.%s.lck", name, t+1);
-  t[0] = '/';
- }
- else sprintf(ret, ".%s.lck", name);
- 
- efree(&name);
- return ret;
-}
- 
-
- 
-static int 
-file_lock(name)
- char * name;
-{
- char * lock = file_lock_name(name);
- int fd = -1;
- char buf[20];
- fd = open(lock, O_WRONLY|O_CREAT|O_EXCL, 0600);
- efree(&lock);
- if(fd < 0)
-  return -1;
- 
- bzero(buf, sizeof(buf));
- sprintf(buf, "%d", getpid());
- write(fd, buf, strlen(buf));
- close(fd);
- return 0;
-}
-
-static int 
-file_unlock(name)
- char * name;
-{
- char * lock = file_lock_name(name);
- int e = 0;
-
- e = unlink(lock);
- efree(&lock);
- return e;
-}
-
-static int
-file_locked(name)
- char * name;
-{
- struct stat st;
- int e;
- char * lock = file_lock_name(name);
- char asc_pid[20];
- int pid;
- int ret = 0;
- int fd = open(lock, O_RDONLY);
- if(fd < 0)
- {
-  efree(&lock);
-  return 0;
- }
- 
- 
- /*
-  * We check that the process which set the
-  * lock is still alive
-  */
- bzero(asc_pid, sizeof(asc_pid));
- read(fd, asc_pid, sizeof(asc_pid)-1);
- close(fd);
- pid = atoi(asc_pid);
- if(process_alive(pid))
- {
-  log_write("The file %s is locked by process %d. Delete %s if you think this is incorrect\n",
-  		name,
-		pid,
-		lock);
-  ret = 1;		
- }
- else
-  file_unlock(name);
-  
- efree(&lock);
- return ret;
-}
-
-
 /*-----------------------------------------------------------------
  
   Name of the directory which contains the sessions of the current
@@ -147,9 +57,11 @@ static char *
 session_dirname(globals)
  struct arglist * globals;
 {
- char * dir,  * user = arg_get_value(globals,"user");
- dir = emalloc(strlen(NESSUSD_STATEDIR) + strlen(user) + strlen("sessions") + 3);
- sprintf(dir, "%s/%s/sessions", NESSUSD_STATEDIR, user);
+ char * home = user_home(globals);
+ char * dir;
+ dir = emalloc(strlen(home) + strlen("sessions") + 2);
+ sprintf(dir, "%s/sessions", home);
+ efree(&home);
  return(dir);
 }
 
@@ -167,8 +79,7 @@ static int
 session_mkdir(dir)
  char * dir;
 {
-  char *t = strchr(dir+1, '/');
- int e;
+ char *t = strchr(dir+1, '/');
  while(t)
  {
   t[0] = '\0';
@@ -291,7 +202,6 @@ save_tests_init(globals)
  strftime(asctime, 2048, "%Y%m%d-%H%M%S", lt);
  
  
- 
  dir = session_dirname(globals);
  session_mkdir(dir);
  efree(&dir);
@@ -299,7 +209,7 @@ save_tests_init(globals)
  index_fname = session_fname(globals, asctime, "index");
  data_fname  = session_fname(globals, asctime, "data");
  
- index = open(index_fname, O_CREAT|O_WRONLY|O_EXCL|O_SYNC, 0600);
+ index = open(index_fname, O_CREAT|O_WRONLY|O_EXCL, 0600);
  file_lock(index_fname);
  if(index < 0)
  {
@@ -324,20 +234,20 @@ save_tests_init(globals)
   {
    char * s = arg_get_value(globals, "save_tests_index_fname");
    efree(&s);
-   arg_set_value(globals, "save_tests_index_fname", strlen(index_fname), strdup(index_fname));
+   arg_set_value(globals, "save_tests_index_fname", strlen(index_fname), estrdup(index_fname));
   }
   else
    arg_add_value(globals, 
    		 "save_tests_index_fname", 
 		 ARG_STRING, 
 		 strlen(index_fname),
-   		 strdup(index_fname));
+   		 estrdup(index_fname));
 		 
   write(index, target, strlen(target));
   write(index, "\n", 1);
  }
  
- data = open(data_fname, O_CREAT|O_WRONLY|O_EXCL|O_SYNC, 0600);
+ data = open(data_fname, O_CREAT|O_WRONLY|O_EXCL, 0600);
  file_lock(data_fname);
  if(data <  0)
  {
@@ -352,14 +262,14 @@ save_tests_init(globals)
   {
    char * s = arg_get_value(globals, "save_tests_data_fname");
    efree(&s);
-   arg_set_value(globals, "save_tests_data_fname", strlen(data_fname), strdup(data_fname));
+   arg_set_value(globals, "save_tests_data_fname", strlen(data_fname), estrdup(data_fname));
   }
   else
    arg_add_value(globals, 
    		 "save_tests_data_fname", 
 		 ARG_STRING, 
 		 strlen(data_fname),
-   		 strdup(data_fname));	 
+   		 estrdup(data_fname));	 
 		 
 		 
   if(arg_get_value(globals, "save_tests_data"))
@@ -373,6 +283,7 @@ save_tests_init(globals)
 bye :
  efree(&data_fname);
  efree(&index_fname);
+ efree(&asctime);
  return ret;
 }
 
@@ -562,6 +473,7 @@ save_tests_setup_playback(globals, session)
  char * target;
  struct arglist * prefs;
  char * plugin_set;
+ int len;
  
  session = estrdup(session);
  
@@ -587,15 +499,16 @@ save_tests_setup_playback(globals, session)
   }
  
  stat(index, &st);
+ len = (int)st.st_size;
  
  /*
   * Get the first line of our file, which contains the 
   * list of hosts to test
   */
- buf = mmap(NULL, st.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
+ buf = mmap(NULL, len, PROT_READ, MAP_PRIVATE, fd, 0);
  t = buf;
  while(t[length] && t[length]!='\n')length++;
- munmap(buf, st.st_size);
+ munmap(buf, len);
  close(fd);
  
  target = emalloc(length+3);
@@ -726,7 +639,7 @@ save_tests_empty(globals)
  if(!f)
  {
   /* ??? */
-   log_write("user %s : Could not re-open %s\n", arg_get_value(globals, "user"), data_fname); 
+   log_write("user %s : Could not re-open %s\n", (char*)arg_get_value(globals, "user"), data_fname); 
    return 0;
  }
  else
@@ -773,6 +686,7 @@ save_tests_delete_current(globals)
  save_tests_close(globals);
  unlink(index_fname);
  unlink(data_fname);
+ return 0;
 }
  
  
