@@ -77,12 +77,7 @@ make_em_die
 {
   /* number of times, the sig is sent at most */
   int n = 3 ;
-  
-# ifdef DEBUG
-  extern int single_shot ;
-  if (single_shot)
-    return ;
-# endif
+
 
   /* leave if we are session leader */
   if (getpgrp () != getpid()) return ;
