@@ -19,16 +19,13 @@
 #ifndef _NESSUSD_USERS_H
 #define _NESSUSD_USERS_H
 
-struct users {
- char * name;
- char * password;
- struct nessus_rules * rules;
- struct users * next;
- };
+
 
 #define BAD_LOGIN_ATTEMPT (struct nessus_rules*)(-1)
+#define NESSUS_MAX_USERNAME_LEN	32 /* Including the ending nul byte! */
 
-int users_init(struct users **, struct arglist *, int silent);
-struct nessus_rules * check_user(struct users *, char * , char *, char *);
+char * user_home(struct arglist*);
+
+struct nessus_rules * check_user(char * , char *, char*);
 void users_add_rule(struct nessus_rules *, char *);
 #endif
