@@ -154,7 +154,8 @@ list2arglist(list)
  * Get the max number of hosts to test at the same time
  */
 int 
-get_max_hosts_number(preferences)
+get_max_hosts_number(globals, preferences)
+ struct arglist * globals;
  struct arglist * preferences;
 {
   int max_hosts;
@@ -167,7 +168,7 @@ get_max_hosts_number(preferences)
 		    max_hosts, (char *)arg_get_value(preferences, "config_file"));
 	  max_hosts = g_max_hosts;
 	}
-    else if(max_hosts > g_max_hosts)
+    else if(max_hosts > g_max_hosts && preferences_user_is_admin(globals, preferences) <= 0)
      {
      	log_write("Client tried to raise the maximum hosts number - %d. Using %d. Change 'max_hosts' in nessusd.conf if \
 you believe this is incorrect\n",
@@ -184,7 +185,8 @@ you believe this is incorrect\n",
  * host at the same time
  */
 int
-get_max_checks_number(preferences)
+get_max_checks_number(globals, preferences)
+ struct arglist * globals;
  struct arglist * preferences;
 {
  int max_checks;
@@ -197,7 +199,7 @@ get_max_checks_number(preferences)
 		    max_checks, (char *)arg_get_value(preferences, "config_file"));
 	  max_checks = g_max_checks;
 	}
-    else if(max_checks > g_max_checks)
+    else if(max_checks > g_max_checks && preferences_user_is_admin(globals, preferences) <= 0)
      {
      	log_write("Client tried to raise the maximum checks number - %d. Using %d. Change 'max_checks' in nessusd.conf if \
 you believe this is incorrect\n",
@@ -391,14 +393,14 @@ process_alive(pid)
  pid_t pid;
 {
  int i, ret;
- if(!pid) 
+ if( pid == 0 ) 
   return 0;
  
- for(i=0,ret=1;(i<100) && (ret > 0);i++)
+ for(i=0,ret=1;(i<10) && (ret > 0);i++)
    ret = waitpid(pid, NULL, WNOHANG);
    
    
- return kill(pid, 0) >= 0;
+ return kill(pid, 0) == 0;
 }
 /*---------------------------------------------------------------------
 
@@ -415,12 +417,19 @@ is_client_present(soc)
 	int soc;
 {
 	fd_set  rd;
-	struct timeval tv = {2,0};
+	struct timeval tv;
 	int m;
+	int e;
 
 	stream_zero(&rd);
 	m = stream_set(soc, &rd);
-	if(select(m+1, &rd, NULL, NULL, &tv) > 0)
+again:
+	tv.tv_sec = 2;
+	tv.tv_usec = 0;
+	e = select(m+1, &rd, NULL, NULL, &tv);
+	if ( e < 0 && errno == EINTR)goto again;
+	
+	if( e > 0 )
 	{
 		int len = data_left(nessus_get_socket_from_connection(soc));
 		if(!len){
